"""
Paygent SDK Constants

This module contains constants for service providers and AI models.
Auto-generated from Node.js SDK constants.
"""

# Service Provider Constants
class ServiceProvider:
    """Service provider constants for external access."""
    # AI/LLM Service Providers
    AI21 = "AI21 Labs"
    AMAZON_POLLY = "Amazon Polly"
    ANTHROPIC = "Anthropic"
    ANYSCALE = "Anyscale"
    ASSEMBLYAI = "AssemblyAI"
    AZURE_AI = "Azure AI"
    AZURE_OPENAI = "Azure OpenAI"
    AZURE_SPEECH = "Azure Speech Service"
    BEDROCK = "AWS Bedrock"
    CEREBRAS = "Cerebras"
    COHERE = "Cohere"
    DASHSCOPE = "DashScope (Ali Cloud)"
    DEEPBRICKS = "DeepBricks"
    DEEPGRAM = "Deepgram"
    DEEPINFRA = "DeepInfra"
    DEEPSEEK = "DeepSeek"
    ELEVENLABS = "ElevenLabs"
    FIREWORKS_AI = "Fireworks AI"
    GOOGLE_STT = "Google Cloud Speech-to-Text"
    GOOGLE_TTS = "Google Cloud Text-to-Speech"
    GOOGLE = "Google"
    GROQ = "Groq"
    JINA = "Jina AI"
    MISTRAL_AI = "Mistral AI"
    MONSTERAPI = "MonsterAPI"
    NEBIUS = "Nebius"
    NOMIC = "Nomic"
    NOVITA_AI = "Novita AI"
    OPENAI = "OpenAI"
    OPENROUTER = "OpenRouter"
    ORACLE = "Oracle"
    PALM = "PaLM"
    PERPLEXITY_AI = "Perplexity AI"
    PREDIBASE = "Predibase"
    REKA_AI = "Reka AI"
    SAGEMAKER = "AWS Sagemaker"
    SEGMIND = "Segmind"
    SONIOX = "Soniox"
    STABILITY_AI = "Stability AI"
    TOGETHER_AI = "Together AI"
    VERTEX_AI = "Google Vertex AI"
    WORKERS_AI = "Cloudflare Workers AI"
    X_AI = "xAI"
    ZHIPU = "Zhipu AI"
    CUSTOM = "Custom"
    
    # Legacy aliases for backward compatibility
    GOOGLE_DEEPMIND = "Google DeepMind"
    META = "Meta"
    AWS = "AWS"
    MOONSHOT_AI = "Moonshot AI"
    
    # STT Service Providers (aliases)
    MICROSOFT_AZURE_SPEECH = "Microsoft Azure Speech Service"
    GOOGLE_CLOUD_SPEECH = "Google Cloud Speech-to-Text"
    ASSEMBLY_AI = "AssemblyAI"
    ELEVEN_LABS_STT = "Eleven Labs STT"
    
    # TTS Service Providers (aliases)
    MICROSOFT_AZURE_SPEECH_TTS = "Microsoft Azure Speech Service"
    GOOGLE_CLOUD_TEXT_TO_SPEECH = "Google Cloud Text-to-Speech"
    DEEPGRAM_TTS = "Deepgram"
    ELEVEN_LABS_TTS = "Eleven Labs TTS"


# AI21Models
class AI21Models:
    """AI21Models constants."""
    JAMBA_1_5_MINI = "jamba-1.5-mini"
    JAMBA_1_5_LARGE = "jamba-1.5-large"


# AmazonPollyModels
class AmazonPollyModels:
    """AmazonPollyModels constants."""
    AMAZON_STANDARD = "amazon-standard"
    NEURAL = "neural"
    LONG_FORM = "long-form"
    GENERATIVE = "generative"


# AnthropicModels
class AnthropicModels:
    """AnthropicModels constants."""
    CLAUDE_2_1 = "claude-2.1"
    CLAUDE_3_5_SONNET_20241022 = "claude-3-5-sonnet-20241022"
    CLAUDE_3_5_SONNET_LATEST = "claude-3-5-sonnet-latest"
    CLAUDE_3_5_HAIKU_20241022 = "claude-3-5-haiku-20241022"
    CLAUDE_3_5_HAIKU_LATEST = "claude-3-5-haiku-latest"
    CLAUDE_3_OPUS_20240229 = "claude-3-opus-20240229"
    CLAUDE_3_OPUS_LATEST = "claude-3-opus-latest"
    CLAUDE_3_SONNET_20240229 = "claude-3-sonnet-20240229"
    CLAUDE_3_HAIKU_20240307 = "claude-3-haiku-20240307"
    CLAUDE_3_5_SONNET_20240620 = "claude-3-5-sonnet-20240620"
    CLAUDE_3_7_SONNET_LATEST = "claude-3-7-sonnet-latest"
    CLAUDE_3_7_SONNET_20250219 = "claude-3-7-sonnet-20250219"
    CLAUDE_OPUS_4_20250514 = "claude-opus-4-20250514"
    CLAUDE_OPUS_4_0 = "claude-opus-4-0"
    CLAUDE_SONNET_4_20250514 = "claude-sonnet-4-20250514"
    CLAUDE_SONNET_4_0 = "claude-sonnet-4-0"
    CLAUDE_OPUS_4_1_20250805 = "claude-opus-4-1-20250805"
    CLAUDE_OPUS_4_1 = "claude-opus-4-1"
    CLAUDE_4_OPUS_20250514 = "claude-4-opus-20250514"
    CLAUDE_SONNET_4_5_20250929 = "claude-sonnet-4-5-20250929"
    CLAUDE_HAIKU_4_5_20251001 = "claude-haiku-4-5-20251001"
    CLAUDE_OPUS_4_5_20251101 = "claude-opus-4-5-20251101"
    CLAUDE_OPUS_4_5 = "claude-opus-4-5"
    CLAUDE_SONNET_4_5 = "claude-sonnet-4-5"


# AnyscaleModels
class AnyscaleModels:
    """AnyscaleModels constants."""
    META_LLAMA_LLAMA_2_7B_CHAT_HF = "meta-llama/Llama-2-7b-chat-hf"
    META_LLAMA_LLAMA_2_13B_CHAT_HF = "meta-llama/Llama-2-13b-chat-hf"
    META_LLAMA_LLAMA_2_70B_CHAT_HF = "meta-llama/Llama-2-70b-chat-hf"
    CODELLAMA_CODELLAMA_34B_INSTRUCT_HF = "codellama/CodeLlama-34b-Instruct-hf"
    MISTRALAI_MISTRAL_7B_INSTRUCT_V0_1 = "mistralai/Mistral-7B-Instruct-v0.1"
    MISTRALAI_MIXTRAL_8X7B_INSTRUCT_V0_1 = "mistralai/Mixtral-8x7B-Instruct-v0.1"
    OPEN_ORCA_MISTRAL_7B_OPENORCA = "Open-Orca/Mistral-7B-OpenOrca"
    THENLPER_GTE_LARGE = "thenlper/gte-large"
    HUGGINGFACEH4_ZEPHYR_7B_BETA = "HuggingFaceH4/zephyr-7b-beta"
    META_LLAMA_LLAMA_GUARD_7B = "Meta-Llama/Llama-Guard-7b"
    BAAI_BGE_LARGE_EN_V1_5 = "BAAI/bge-large-en-v1.5"
    MLABONNE_NEURALHERMES_2_5_MISTRAL_7B = "mlabonne/NeuralHermes-2.5-Mistral-7B"
    CODELLAMA_CODELLAMA_70B_INSTRUCT_HF = "codellama/CodeLlama-70b-Instruct-hf"
    META_LLAMA_LLAMA_3_8B_CHAT_HF = "meta-llama/Llama-3-8b-chat-hf"
    META_LLAMA_META_LLAMA_3_70B_INSTRUCT = "meta-llama/Meta-Llama-3-70B-Instruct"
    GOOGLE_GEMMA_7B_IT = "google/gemma-7b-it"
    MISTRALAI_MIXTRAL_8X22B_INSTRUCT_V0_1 = "mistralai/Mixtral-8x22B-Instruct-v0.1"


# AssemblyAIModels
class AssemblyAIModels:
    """AssemblyAIModels constants."""
    UNIVERSAL_STREAMING = "universal-streaming"
    UNIVERSAL_STREAMING_MULTILANG = "universal-streaming-multilang"
    KEYTERMS_PROMPTING = "keyterms-prompting"


# AzureAIModels
class AzureAIModels:
    """AzureAIModels constants."""
    GPT_4_VISION_PREVIEW = "gpt-4-vision-preview"
    GPT_3_5_TURBO_1106 = "gpt-3.5-turbo-1106"
    TEXT_EMBEDDING_ADA_002 = "text-embedding-ada-002"
    TEXT_EMBEDDING_3_SMALL = "text-embedding-3-small"
    TEXT_EMBEDDING_3_LARGE = "text-embedding-3-large"
    GPT_4_32K_0613 = "gpt-4-32k-0613"
    GPT_3_5_TURBO_0613 = "gpt-3.5-turbo-0613"
    GPT_3_5_TURBO_16K = "gpt-3.5-turbo-16k"
    GPT_35_TURBO_16K = "gpt-35-turbo-16k"
    GPT_35_TURBO_1106 = "gpt-35-turbo-1106"
    GPT_4_1106_PREVIEW = "gpt-4-1106-preview"
    GPT_4 = "gpt-4"
    GPT_4_0314 = "gpt-4-0314"
    GPT_4_32K = "gpt-4-32k"
    GPT_4_32K_0314 = "gpt-4-32k-0314"
    GPT_3_5_TURBO_0301 = "gpt-3.5-turbo-0301"
    GPT_3_5_TURBO = "gpt-3.5-turbo"
    GPT_35_TURBO = "gpt-35-turbo"
    TEXT_MODERATION_004 = "text-moderation-004"
    TEXT_DAVINCI_003 = "text-davinci-003"
    TEXT_DAVINCI_002 = "text-davinci-002"
    TEXT_CURIE_001 = "text-curie-001"
    TEXT_BABBAGE_001 = "text-babbage-001"
    TEXT_ADA_001 = "text-ada-001"
    TEXT_DAVINCI_001 = "text-davinci-001"
    GPT_4_0613 = "gpt-4-0613"
    DAVINCI = "davinci"
    GPT_35_TURBO_0613_FT = "gpt-35-turbo-0613.ft"
    GPT_35_TURBO_1106_FT = "gpt-35-turbo-1106.ft"
    GPT_35_TURBO_0125_FT = "gpt-35-turbo-0125.ft"
    ADA = "ada"
    GPT_4_TURBO = "gpt-4-turbo"
    GPT_4_TURBO_2024_04_09 = "gpt-4-turbo-2024-04-09"
    GPT_4O = "gpt-4o"
    GPT_4O_2024_05_13 = "gpt-4o-2024-05-13"
    GPT_4O_2024_08_06 = "gpt-4o-2024-08-06"
    CHATGPT_4O_LATEST = "chatgpt-4o-latest"
    GPT_4O_MINI = "gpt-4o-mini"
    GPT_4O_MINI_2024_07_18 = "gpt-4o-mini-2024-07-18"
    GPT_4_0125_PREVIEW = "gpt-4-0125-preview"
    TTS_1 = "tts-1"
    TTS_1_HD = "tts-1-hd"
    TTS = "tts"
    TTS_HD = "tts-hd"
    O1 = "o1"
    O1_2024_12_17 = "o1-2024-12-17"
    O1_PREVIEW = "o1-preview"
    O1_PREVIEW_2024_09_12 = "o1-preview-2024-09-12"
    O1_MINI = "o1-mini"
    O1_MINI_2024_09_12 = "o1-mini-2024-09-12"
    GPT_4O_REALTIME_PREVIEW_2024_10_01 = "gpt-4o-realtime-preview-2024-10-01"
    TEXT_MODERATION_STABLE = "text-moderation-stable"
    TEXT_MODERATION_LATEST = "text-moderation-latest"
    TEXT_MODERATION_001 = "text-moderation-001"
    CODE_DAVINCI_002 = "code-davinci-002"
    CODE_CUSHMAN_001 = "code-cushman-001"
    GPT_4O_2024_11_20 = "gpt-4o-2024-11-20"
    O3_MINI_2025_01_31 = "o3-mini-2025-01-31"
    O3_MINI = "o3-mini"
    GPT_4_5_PREVIEW_2025_02_27 = "gpt-4.5-preview-2025-02-27"
    GPT_4_1_2025_04_14 = "gpt-4.1-2025-04-14"
    GPT_4_1 = "gpt-4.1"
    GPT_4_1_MINI_2025_04_14 = "gpt-4.1-mini-2025-04-14"
    GPT_4_1_MINI = "gpt-4.1-mini"
    GPT_4_1_NANO_2025_04_14 = "gpt-4.1-nano-2025-04-14"
    GPT_4_1_NANO = "gpt-4.1-nano"
    O3 = "o3"
    O3_2025_04_16 = "o3-2025-04-16"
    O4_MINI = "o4-mini"
    O4_MINI_2025_04_16 = "o4-mini-2025-04-16"
    META_LLAMA_3_8B_INSTRUCT = "Meta-Llama-3-8B-Instruct"
    LLAMA_3_3_70B_INSTRUCT = "Llama-3.3-70B-Instruct"
    META_LLAMA_3_1_405B_INSTRUCT = "Meta-Llama-3.1-405B-Instruct"
    LLAMA_4_SCOUT_17B_16E_INSTRUCT = "Llama-4-Scout-17B-16E-Instruct"
    LLAMA_4_MAVERICK_17B_128E_INSTRUCT_FP8 = "Llama-4-Maverick-17B-128E-Instruct-FP8"
    LLAMA_2_70B_CHAT = "Llama-2-70b-chat"
    LLAMA_2_7B_CHAT = "Llama-2-7b-chat"
    META_LLAMA_3_1_8B_INSTRUCT = "Meta-Llama-3.1-8B-Instruct"
    LLAMA_3_2_90B_VISION_INSTRUCT = "Llama-3.2-90B-Vision-Instruct"
    LLAMA_3_2_11B_VISION_INSTRUCT = "Llama-3.2-11B-Vision-Instruct"
    META_LLAMA_3_1_70B_INSTRUCT = "Meta-Llama-3.1-70B-Instruct"
    META_LLAMA_3_70B_INSTRUCT = "Meta-Llama-3-70B-Instruct"
    CODESTRAL_2501 = "codestral-2501"
    CODESTRAL_2501_1 = "Codestral-2501"
    MISTRAL_NEMO = "Mistral-Nemo"
    MISTRAL_LARGE_2411 = "mistral-large-2411"
    MINISTRAL_3B_2410 = "ministral-3b-2410"
    MISTRAL_LARGE_2411_1 = "Mistral-Large-2411"
    MISTRAL_SMALL_2503 = "mistral-small-2503"
    PHI4_MINI_INSTRUCT = "phi4-mini-instruct"
    PHI_4_MINI_INSTRUCT = "Phi-4-mini-instruct"
    PHI_4_MULTILMODAL_INSTRUCT = "Phi-4-multilmodal-instruct"
    PHI_4_MULTIMODAL_INSTRUCT = "Phi-4-multimodal-instruct"
    PHI4 = "phi4"
    PHI_4 = "Phi-4"
    PHI35_MINI_INSTRUCT = "phi35-mini-instruct"
    PHI_3_5_MINI_INSTRUCT = "Phi-3.5-mini-instruct"
    PHI3_MEDIUM_4K = "phi3-medium-4k"
    PHI35_MOE_INSTRUCT = "phi35-moe-instruct"
    PHI_3_5_MOE_INSTRUCT = "Phi-3.5-MoE-instruct"
    PHI35_VISION_INSTRUCT = "phi35-vision-instruct"
    PHI_3_5_VISION_INSTRUCT = "Phi-3.5-vision-instruct"
    DEEPSEEK_V3 = "DeepSeek-V3"
    DEEPSEEK_V3_0324 = "DeepSeek-V3-0324"
    DEEPSEEK_R1 = "deepseek-r1"
    DEEPSEEK_R1_1 = "DeepSeek-R1"
    COHERE_COMMAND_R_PLUS_08_2024 = "Cohere-command-r-plus-08-2024"
    POSEIDON = "poseidon"
    COHERE_COMMAND_R_08_2024 = "Cohere-command-r-08-2024"
    JAMBA_1_5_MINI = "jamba-1.5-mini"
    AI21_JAMBA_1_5_MINI = "AI21-Jamba-1.5-Mini"
    JAMBA_1_5_LARGE = "jamba-1.5-large"
    AI21_JAMBA_1_5_LARGE = "AI21-Jamba-1.5-Large"
    STABLE_DIFFUSION_3_5_LARGE = "Stable-Diffusion-3.5-Large"
    STABLE_IMAGE_ULTRA = "Stable-Image-Ultra"
    STABLE_IMAGE_CORE = "Stable-Image-Core"
    GPT_4O_FT = "gpt-4o.ft"
    GPT_4O_2024_08_06_FT = "gpt-4o-2024-08-06.ft"
    GPT_4O_MINI_FT = "gpt-4o-mini.ft"
    GPT_4O_MINI_2024_07_18_FT = "gpt-4o-mini-2024-07-18.ft"
    GPT_4_1_2025_04_14_FT = "gpt-4.1-2025-04-14.ft"
    GPT_4_1_FT = "gpt-4.1.ft"
    GPT_4_1_MINI_2025_04_14_FT = "gpt-4.1-mini-2025-04-14.ft"
    GPT_4_1_MINI_FT = "gpt-4.1-mini.ft"
    DALL_E_3 = "dall-e-3"
    DALL_E_2 = "dall-e-2"
    O3_DEEP_RESEARCH = "o3-deep-research"
    O3_DEEP_RESEARCH_2025_06_26 = "o3-deep-research-2025-06-26"
    O4_MINI_DEEP_RESEARCH_2025_06_26 = "o4-mini-deep-research-2025-06-26"
    O4_MINI_DEEP_RESEARCH = "o4-mini-deep-research"
    GPT_4O_MINI_REALTIME_PREVIEW = "gpt-4o-mini-realtime-preview"
    GPT_4O_MINI_REALTIME_PREVIEW_2024_12_17 = "gpt-4o-mini-realtime-preview-2024-12-17"
    GPT_4O_SEARCH_PREVIEW = "gpt-4o-search-preview"
    GPT_4O_SEARCH_PREVIEW_2025_03_11 = "gpt-4o-search-preview-2025-03-11"
    GPT_4O_MINI_SEARCH_PREVIEW_2025_03_11 = "gpt-4o-mini-search-preview-2025-03-11"
    GPT_4O_MINI_SEARCH_PREVIEW = "gpt-4o-mini-search-preview"
    CODEX_MINI_LATEST = "codex-mini-latest"
    GPT_4O_REALTIME_PREVIEW_2025_06_03 = "gpt-4o-realtime-preview-2025-06-03"
    GPT_5_2025_08_07 = "gpt-5-2025-08-07"
    GPT_5 = "gpt-5"
    GPT_5_MINI = "gpt-5-mini"
    GPT_5_MINI_2025_08_07 = "gpt-5-mini-2025-08-07"
    GPT_5_NANO = "gpt-5-nano"
    GPT_5_NANO_2025_08_07 = "gpt-5-nano-2025-08-07"
    GPT_5_CHAT_LATEST = "gpt-5-chat-latest"
    GPT_5_CODEX = "gpt-5-codex"
    GPT_4O_MINI_AUDIO_PREVIEW = "gpt-4o-mini-audio-preview"
    GPT_4O_MINI_AUDIO_PREVIEW_2024_12_17 = "gpt-4o-mini-audio-preview-2024-12-17"
    GPT_5_PRO = "gpt-5-pro"
    GPT_5_PRO_2025_10_06 = "gpt-5-pro-2025-10-06"
    GPT_REALTIME = "gpt-realtime"
    GPT_REALTIME_2025_08_28 = "gpt-realtime-2025-08-28"
    GPT_AUDIO = "gpt-audio"
    GPT_AUDIO_MINI = "gpt-audio-mini"
    O3_PRO = "o3-pro"
    O3_PRO_2025_06_10 = "o3-pro-2025-06-10"
    O1_PRO = "o1-pro"
    O1_PRO_2025_03_19 = "o1-pro-2025-03-19"
    GPT_4O_REALTIME_PREVIEW = "gpt-4o-realtime-preview"
    GPT_IMAGE_1 = "gpt-image-1"
    GPT_5_1 = "gpt-5.1"
    GPT_5_1_2025_11_13 = "gpt-5.1-2025-11-13"
    GPT_5_1_CODEX = "gpt-5.1-codex"
    GPT_5_1_CODEX_MINI = "gpt-5.1-codex-mini"
    GPT_5_1_CHAT_LATEST = "gpt-5.1-chat-latest"
    CLAUDE_OPUS_4_5_20251101 = "claude-opus-4-5-20251101"
    CLAUDE_SONNET_4_5_20250929 = "claude-sonnet-4-5-20250929"
    CLAUDE_HAIKU_4_5_20251001 = "claude-haiku-4-5-20251001"
    CLAUDE_OPUS_4_1_20250805 = "claude-opus-4-1-20250805"
    GPT_5_SEARCH_API_2025_10_14 = "gpt-5-search-api-2025-10-14"
    GPT_5_SEARCH_API = "gpt-5-search-api"
    GPT_IMAGE_1_5 = "gpt-image-1.5"
    GPT_IMAGE_1_5_2025_12_16 = "gpt-image-1.5-2025-12-16"
    MISTRAL_LARGE_3 = "Mistral-Large-3"


# AzureOpenAIModels
class AzureOpenAIModels:
    """AzureOpenAIModels constants."""
    GPT_4_VISION_PREVIEW = "gpt-4-vision-preview"
    GPT_3_5_TURBO_1106 = "gpt-3.5-turbo-1106"
    TEXT_EMBEDDING_ADA_002 = "text-embedding-ada-002"
    TEXT_EMBEDDING_3_SMALL = "text-embedding-3-small"
    TEXT_EMBEDDING_3_LARGE = "text-embedding-3-large"
    GPT_4_32K_0613 = "gpt-4-32k-0613"
    GPT_3_5_TURBO_0613 = "gpt-3.5-turbo-0613"
    GPT_3_5_TURBO_16K = "gpt-3.5-turbo-16k"
    GPT_35_TURBO_16K = "gpt-35-turbo-16k"
    GPT_35_TURBO_1106 = "gpt-35-turbo-1106"
    GPT_4_1106_PREVIEW = "gpt-4-1106-preview"
    GPT_4 = "gpt-4"
    GPT_4_0314 = "gpt-4-0314"
    GPT_4_32K = "gpt-4-32k"
    GPT_4_32K_0314 = "gpt-4-32k-0314"
    GPT_3_5_TURBO_0301 = "gpt-3.5-turbo-0301"
    GPT_3_5_TURBO = "gpt-3.5-turbo"
    GPT_35_TURBO = "gpt-35-turbo"
    TEXT_MODERATION_004 = "text-moderation-004"
    TEXT_DAVINCI_003 = "text-davinci-003"
    TEXT_DAVINCI_002 = "text-davinci-002"
    TEXT_CURIE_001 = "text-curie-001"
    TEXT_BABBAGE_001 = "text-babbage-001"
    TEXT_ADA_001 = "text-ada-001"
    TEXT_DAVINCI_001 = "text-davinci-001"
    GPT_4_0613 = "gpt-4-0613"
    DAVINCI = "davinci"
    GPT_35_TURBO_0613_FT = "gpt-35-turbo-0613.ft"
    GPT_35_TURBO_1106_FT = "gpt-35-turbo-1106.ft"
    GPT_35_TURBO_0125_FT = "gpt-35-turbo-0125.ft"
    ADA = "ada"
    GPT_4_TURBO = "gpt-4-turbo"
    GPT_4_TURBO_2024_04_09 = "gpt-4-turbo-2024-04-09"
    GPT_4O = "gpt-4o"
    GPT_4O_2024_05_13 = "gpt-4o-2024-05-13"
    GPT_4O_2024_08_06 = "gpt-4o-2024-08-06"
    CHATGPT_4O_LATEST = "chatgpt-4o-latest"
    GPT_4O_MINI = "gpt-4o-mini"
    GPT_4O_MINI_2024_07_18 = "gpt-4o-mini-2024-07-18"
    GPT_4_0125_PREVIEW = "gpt-4-0125-preview"
    TTS_1 = "tts-1"
    TTS_1_HD = "tts-1-hd"
    TTS = "tts"
    TTS_HD = "tts-hd"
    O1 = "o1"
    O1_2024_12_17 = "o1-2024-12-17"
    O1_PREVIEW = "o1-preview"
    O1_PREVIEW_2024_09_12 = "o1-preview-2024-09-12"
    O1_MINI = "o1-mini"
    O1_MINI_2024_09_12 = "o1-mini-2024-09-12"
    GPT_4O_REALTIME_PREVIEW_2024_10_01 = "gpt-4o-realtime-preview-2024-10-01"
    GPT_4O_REALTIME_PREVIEW = "gpt-4o-realtime-preview"
    TEXT_MODERATION_STABLE = "text-moderation-stable"
    TEXT_MODERATION_LATEST = "text-moderation-latest"
    TEXT_MODERATION_001 = "text-moderation-001"
    CODE_DAVINCI_002 = "code-davinci-002"
    CODE_CUSHMAN_001 = "code-cushman-001"
    GPT_4O_2024_11_20 = "gpt-4o-2024-11-20"
    GPT_4O_MINI_TTS = "gpt-4o-mini-tts"
    GPT_4O_TRANSCRIBE = "gpt-4o-transcribe"
    GPT_4O_MINI_TRANSCRIBE = "gpt-4o-mini-transcribe"
    O3_MINI_2025_01_31 = "o3-mini-2025-01-31"
    O3_MINI = "o3-mini"
    GPT_4_5_PREVIEW_2025_02_27 = "gpt-4.5-preview-2025-02-27"
    COMPUTER_USE_PREVIEW = "computer-use-preview"
    DALL_E_3 = "dall-e-3"
    DALL_E_2 = "dall-e-2"
    GPT_4_1_2025_04_14 = "gpt-4.1-2025-04-14"
    GPT_4_1 = "gpt-4.1"
    GPT_4_1_MINI_2025_04_14 = "gpt-4.1-mini-2025-04-14"
    GPT_4_1_MINI = "gpt-4.1-mini"
    GPT_4_1_NANO_2025_04_14 = "gpt-4.1-nano-2025-04-14"
    GPT_4_1_NANO = "gpt-4.1-nano"
    O3 = "o3"
    O3_2025_04_16 = "o3-2025-04-16"
    O3_PRO = "o3-pro"
    O3_PRO_2025_06_10 = "o3-pro-2025-06-10"
    O4_MINI = "o4-mini"
    O4_MINI_2025_04_16 = "o4-mini-2025-04-16"
    GPT_4O_FT = "gpt-4o.ft"
    GPT_4O_2024_08_06_FT = "gpt-4o-2024-08-06.ft"
    GPT_4O_MINI_FT = "gpt-4o-mini.ft"
    GPT_4O_MINI_2024_07_18_FT = "gpt-4o-mini-2024-07-18.ft"
    GPT_4_1_2025_04_14_FT = "gpt-4.1-2025-04-14.ft"
    GPT_4_1_FT = "gpt-4.1.ft"
    GPT_4_1_MINI_2025_04_14_FT = "gpt-4.1-mini-2025-04-14.ft"
    GPT_4_1_MINI_FT = "gpt-4.1-mini.ft"
    O3_DEEP_RESEARCH = "o3-deep-research"
    O3_DEEP_RESEARCH_2025_06_26 = "o3-deep-research-2025-06-26"
    O4_MINI_DEEP_RESEARCH_2025_06_26 = "o4-mini-deep-research-2025-06-26"
    O4_MINI_DEEP_RESEARCH = "o4-mini-deep-research"
    GPT_4O_MINI_REALTIME_PREVIEW_2024_12_17 = "gpt-4o-mini-realtime-preview-2024-12-17"
    GPT_4O_SEARCH_PREVIEW = "gpt-4o-search-preview"
    GPT_4O_SEARCH_PREVIEW_2025_03_11 = "gpt-4o-search-preview-2025-03-11"
    GPT_4O_MINI_SEARCH_PREVIEW_2025_03_11 = "gpt-4o-mini-search-preview-2025-03-11"
    GPT_4O_MINI_SEARCH_PREVIEW = "gpt-4o-mini-search-preview"
    CODEX_MINI_LATEST = "codex-mini-latest"
    GPT_4O_REALTIME_PREVIEW_2025_06_03 = "gpt-4o-realtime-preview-2025-06-03"
    GPT_5_2025_08_07 = "gpt-5-2025-08-07"
    GPT_5 = "gpt-5"
    GPT_5_MINI = "gpt-5-mini"
    GPT_5_MINI_2025_08_07 = "gpt-5-mini-2025-08-07"
    GPT_5_NANO = "gpt-5-nano"
    GPT_5_NANO_2025_08_07 = "gpt-5-nano-2025-08-07"
    GPT_5_CHAT_LATEST = "gpt-5-chat-latest"
    GPT_5_CODEX = "gpt-5-codex"
    GPT_4O_MINI_AUDIO_PREVIEW = "gpt-4o-mini-audio-preview"
    GPT_4O_MINI_AUDIO_PREVIEW_2024_12_17 = "gpt-4o-mini-audio-preview-2024-12-17"
    GPT_5_PRO = "gpt-5-pro"
    GPT_5_PRO_2025_10_06 = "gpt-5-pro-2025-10-06"
    GPT_REALTIME = "gpt-realtime"
    GPT_REALTIME_2025_08_28 = "gpt-realtime-2025-08-28"
    GPT_AUDIO = "gpt-audio"
    GPT_AUDIO_MINI = "gpt-audio-mini"
    O1_PRO = "o1-pro"
    O1_PRO_2025_03_19 = "o1-pro-2025-03-19"
    GPT_IMAGE_1 = "gpt-image-1"
    SORA_2 = "sora-2"
    SORA_2_PRO = "sora-2-pro"
    GPT_5_1 = "gpt-5.1"
    GPT_5_1_2025_11_13 = "gpt-5.1-2025-11-13"
    GPT_5_1_CODEX = "gpt-5.1-codex"
    GPT_5_1_CODEX_MINI = "gpt-5.1-codex-mini"
    GPT_5_1_CHAT_LATEST = "gpt-5.1-chat-latest"
    GPT_5_SEARCH_API_2025_10_14 = "gpt-5-search-api-2025-10-14"
    GPT_5_SEARCH_API = "gpt-5-search-api"
    GPT_5_2 = "gpt-5.2"
    GPT_5_2_2025_12_11 = "gpt-5.2-2025-12-11"
    GPT_5_2_CHAT_LATEST = "gpt-5.2-chat-latest"
    GPT_5_2_PRO = "gpt-5.2-pro"
    GPT_5_2_PRO_2025_12_11 = "gpt-5.2-pro-2025-12-11"
    GROK_4_FAST_NON_REASONING = "grok-4-fast-non-reasoning"
    GROK_3_MINI = "grok-3-mini"
    GROK_4_FAST_REASONING = "grok-4-fast-reasoning"
    GROK_CODE_FAST_1 = "grok-code-fast-1"
    GROK_4 = "grok-4"
    GROK_3 = "grok-3"
    GPT_4O_TRANSCRIBE_DIARIZE = "gpt-4o-transcribe-diarize"


# AzureSpeechModels
class AzureSpeechModels:
    """AzureSpeechModels constants."""
    AZURE_STANDARD = "azure-standard"
    AZURE_CUSTOM = "azure-custom"
    STANDARD_NEURAL = "standard-neural"
    CUSTOM_SYNTHESIS = "custom-synthesis"
    CUSTOM_SYNTHESIS_NEURAL_HD = "custom-synthesis-neural-hd"


# BedrockModels
class BedrockModels:
    """BedrockModels constants."""
    AMAZON_TITAN_TEXT_EXPRESS_V1 = "amazon.titan-text-express-v1"
    AMAZON_TITAN_TEXT_LITE_V1 = "amazon.titan-text-lite-v1"
    AMAZON_TITAN_EMBED_TEXT_V1 = "amazon.titan-embed-text-v1"
    ANTHROPIC_CLAUDE_V1 = "anthropic.claude-v1"
    ANTHROPIC_CLAUDE_V2 = "anthropic.claude-v2"
    ANTHROPIC_CLAUDE_V2_1 = "anthropic.claude-v2:1"
    ANTHROPIC_CLAUDE_INSTANT_V1 = "anthropic.claude-instant-v1"
    AI21_J2_MID_V1 = "ai21.j2-mid-v1"
    AI21_J2_ULTRA_V1 = "ai21.j2-ultra-v1"
    COHERE_RERANK_V3_5_0 = "cohere.rerank-v3-5:0"
    RERANK_V4_0_FAST = "rerank-v4.0-fast"
    RERANK_V4_0_PRO = "rerank-v4.0-pro"
    COHERE_COMMAND_TEXT_V14 = "cohere.command-text-v14"
    COHERE_COMMAND_LIGHT_TEXT_V14 = "cohere.command-light-text-v14"
    COHERE_EMBED_ENGLISH_V3 = "cohere.embed-english-v3"
    COHERE_EMBED_MULTILINGUAL_V3 = "cohere.embed-multilingual-v3"
    META_LLAMA2_13B_CHAT_V1 = "meta.llama2-13b-chat-v1"
    META_LLAMA2_70B_CHAT_V1 = "meta.llama2-70b-chat-v1"
    ANTHROPIC_CLAUDE_3_SONNET_20240229_V1_0 = "anthropic.claude-3-sonnet-20240229-v1:0"
    ANTHROPIC_CLAUDE_3_HAIKU_20240307_V1_0 = "anthropic.claude-3-haiku-20240307-v1:0"
    MISTRAL_MISTRAL_7B_INSTRUCT_V0_2 = "mistral.mistral-7b-instruct-v0:2"
    MISTRAL_MIXTRAL_8X7B_INSTRUCT_V0_1 = "mistral.mixtral-8x7b-instruct-v0:1"
    MISTRAL_MISTRAL_SMALL_2402_V1_0 = "mistral.mistral-small-2402-v1:0"
    MISTRAL_MISTRAL_LARGE_2407_V1_0 = "mistral.mistral-large-2407-v1:0"
    MISTRAL_MISTRAL_LARGE_2402_V1_0 = "mistral.mistral-large-2402-v1:0"
    META_LLAMA3_8B_INSTRUCT_V1_0 = "meta.llama3-8b-instruct-v1:0"
    META_LLAMA3_70B_INSTRUCT_V1_0 = "meta.llama3-70b-instruct-v1:0"
    ANTHROPIC_CLAUDE_3_OPUS_20240229_V1_0 = "anthropic.claude-3-opus-20240229-v1:0"
    ANTHROPIC_CLAUDE_3_5_SONNET_20240620_V1_0 = "anthropic.claude-3-5-sonnet-20240620-v1:0"
    ANTHROPIC_CLAUDE_3_5_SONNET_20241022_V2_0 = "anthropic.claude-3-5-sonnet-20241022-v2:0"
    ANTHROPIC_CLAUDE_3_5_HAIKU_20241022_V1_0 = "anthropic.claude-3-5-haiku-20241022-v1:0"
    STABILITY_STABLE_DIFFUSION_XL_V0 = "stability.stable-diffusion-xl-v0"
    STABILITY_STABLE_DIFFUSION_XL_V0_PREMIUM = "stability.stable-diffusion-xl-v0::premium"
    STABILITY_STABLE_DIFFUSION_XL_V1 = "stability.stable-diffusion-xl-v1"
    STABILITY_STABLE_DIFFUSION_XL_V1_PREMIUM = "stability.stable-diffusion-xl-v1::premium"
    STABILITY_SD3_LARGE_V1_0 = "stability.sd3-large-v1:0"
    STABILITY_STABLE_IMAGE_ULTRA_V1_0 = "stability.stable-image-ultra-v1:0"
    STABILITY_STABLE_IMAGE_ULTRA_V1_1 = "stability.stable-image-ultra-v1:1"
    STABILITY_STABLE_IMAGE_CORE_V1_0 = "stability.stable-image-core-v1:0"
    STABILITY_STABLE_IMAGE_CORE_V1_1 = "stability.stable-image-core-v1:1"
    META_LLAMA3_1_8B_INSTRUCT_V1_0 = "meta.llama3-1-8b-instruct-v1:0"
    META_LLAMA3_1_70B_INSTRUCT_V1_0 = "meta.llama3-1-70b-instruct-v1:0"
    META_LLAMA3_1_405B_INSTRUCT_V1_0 = "meta.llama3-1-405b-instruct-v1:0"
    META_LLAMA3_2_1B_INSTRUCT_V1_0 = "meta.llama3-2-1b-instruct-v1:0"
    META_LLAMA3_2_3B_INSTRUCT_V1_0 = "meta.llama3-2-3b-instruct-v1:0"
    META_LLAMA3_2_11B_INSTRUCT_V1_0 = "meta.llama3-2-11b-instruct-v1:0"
    META_LLAMA3_2_90B_INSTRUCT_V1_0 = "meta.llama3-2-90b-instruct-v1:0"
    AMAZON_NOVA_PRO_V1_0 = "amazon.nova-pro-v1:0"
    AMAZON_NOVA_LITE_V1_0 = "amazon.nova-lite-v1:0"
    AMAZON_NOVA_MICRO_V1_0 = "amazon.nova-micro-v1:0"
    ANTHROPIC_CLAUDE_3_7_SONNET_20250219_V1_0 = "anthropic.claude-3-7-sonnet-20250219-v1:0"
    DEEPSEEK_R1_V1_0 = "deepseek.r1-v1:0"
    META_LLAMA3_3_70B_INSTRUCT_V1_0 = "meta.llama3-3-70b-instruct-v1:0"
    META_LLAMA4_SCOUT_17B_INSTRUCT_V1_0 = "meta.llama4-scout-17b-instruct-v1:0"
    META_LLAMA4_MAVERICK_17B_INSTRUCT_V1_0 = "meta.llama4-maverick-17b-instruct-v1:0"
    ANTHROPIC_CLAUDE_SONNET_4_20250514_V1_0 = "anthropic.claude-sonnet-4-20250514-v1:0"
    ANTHROPIC_CLAUDE_OPUS_4_20250514_V1_0 = "anthropic.claude-opus-4-20250514-v1:0"
    ANTHROPIC_CLAUDE_OPUS_4_1_20250805_V1_0 = "anthropic.claude-opus-4-1-20250805-v1:0"
    ANTHROPIC_CLAUDE_SONNET_4_5_20250929_V1_0 = "anthropic.claude-sonnet-4-5-20250929-v1:0"
    ANTHROPIC_CLAUDE_HAIKU_4_5_20251001_V1_0 = "anthropic.claude-haiku-4-5-20251001-v1:0"
    ANTHROPIC_CLAUDE_OPUS_4_5_20251101_V1_0 = "anthropic.claude-opus-4-5-20251101-v1:0"
    DEEPSEEK_V3_V1_0 = "deepseek.v3-v1:0"
    COHERE_COMMAND_R_V1_0 = "cohere.command-r-v1:0"
    COHERE_COMMAND_R_PLUS_V1_0 = "cohere.command-r-plus-v1:0"
    AMAZON_TITAN_EMBED_TEXT_V2_0 = "amazon.titan-embed-text-v2:0"
    AMAZON_TITAN_EMBED_IMAGE_V1 = "amazon.titan-embed-image-v1"
    OPENAI_GPT_OSS_20B_1_0 = "openai.gpt-oss-20b-1:0"
    OPENAI_GPT_OSS_120B_1_0 = "openai.gpt-oss-120b-1:0"
    US_AMAZON_NOVA_PRO_V1 = "us.amazon.nova-pro-v1"
    STABILITY_STABLE_IMAGE_CORE_V1 = "stability.stable-image-core-v1"
    STABILITY_STABLE_IMAGE_ULTRA_V1 = "stability.stable-image-ultra-v1"
    STABILITY_SD3_5_LARGE_V1 = "stability.sd3-5-large-v1"
    AMAZON_TITAN_EMBED_G1_TEXT_02 = "amazon.titan-embed-g1-text-02"
    CLAUDE_OPUS_4_5_20251101 = "claude-opus-4-5-20251101"
    CLAUDE_SONNET_4_5_20250929 = "claude-sonnet-4-5-20250929"
    CLAUDE_HAIKU_4_5_20251001 = "claude-haiku-4-5-20251001"


# CerebrasModels
class CerebrasModels:
    """CerebrasModels constants."""
    LLAMA3_1_8B = "llama3.1-8b"
    LLAMA3_1_70B = "llama3.1-70b"
    LLAMA_4_SCOUT_17B_16E_INSTRUCT = "llama-4-scout-17b-16e-instruct"
    LLAMA_4_MAVERICK_17B_128E_INSTRUCT = "llama-4-maverick-17b-128e-instruct"
    LLAMA_3_3_70B = "llama-3.3-70b"
    QWEN_3_32B = "qwen-3-32b"
    QWEN_3_235B_A22B_INSTRUCT_2507 = "qwen-3-235b-a22b-instruct-2507"
    QWEN_3_235B_A22B_THINKING_2507 = "qwen-3-235b-a22b-thinking-2507"
    QWEN_3_CODER_480B = "qwen-3-coder-480b"
    GPT_OSS_120B = "gpt-oss-120b"
    ZAI_GLM_4_6 = "zai-glm-4.6"


# CohereModels
class CohereModels:
    """CohereModels constants."""
    COMMAND = "command"
    COMMAND_LIGHT = "command-light"
    COMMAND_NIGHTLY = "command-nightly"
    COMMAND_LIGHT_NIGHTLY = "command-light-nightly"
    EMBED_ENGLISH_V2_0 = "embed-english-v2.0"
    EMBED_ENGLISH_LIGHT_V2_0 = "embed-english-light-v2.0"
    EMBED_MULTILINGUAL_V2_0 = "embed-multilingual-v2.0"
    EMBED_ENGLISH_V3_0 = "embed-english-v3.0"
    EMBED_MULTILINGUAL_V3_0 = "embed-multilingual-v3.0"
    RERANK_ENGLISH_V3_0 = "rerank-english-v3.0"
    RERANK_MULTILINGUAL_V3_0 = "rerank-multilingual-v3.0"
    COMMAND_R_PLUS = "command-r-plus"
    COMMAND_R = "command-r"
    COMMAND_R7B = "command-r7b"
    RERANK_V3_5 = "rerank-v3.5"
    RERANK_MULTILINGUAL_V2_0 = "rerank-multilingual-v2.0"
    RERANK_ENGLISH_V2_0 = "rerank-english-v2.0"
    RERANK_V4_0_FAST = "rerank-v4.0-fast"
    RERANK_V4_0_PRO = "rerank-v4.0-pro"


# DashScopeModels
class DashScopeModels:
    """DashScopeModels constants."""
    QVQ_MAX = "qvq-max"
    QWEN_CODER = "qwen-coder"
    QWEN_FLASH = "qwen-flash"
    QWEN_FLASH_2025_07_28 = "qwen-flash-2025-07-28"
    QWEN_MAX = "qwen-max"
    QWEN_MT_PLUS = "qwen-mt-plus"
    QWEN_MT_TURBO = "qwen-mt-turbo"
    QWEN_OMNI_TURBO = "qwen-omni-turbo"
    QWEN_OMNI_TURBO_REALTIME = "qwen-omni-turbo-realtime"
    QWEN_PLUS = "qwen-plus"
    QWEN_PLUS_2025_01_25 = "qwen-plus-2025-01-25"
    QWEN_PLUS_2025_04_28 = "qwen-plus-2025-04-28"
    QWEN_PLUS_2025_07_14 = "qwen-plus-2025-07-14"
    QWEN_PLUS_2025_07_28 = "qwen-plus-2025-07-28"
    QWEN_PLUS_2025_09_11 = "qwen-plus-2025-09-11"
    QWEN_PLUS_CHARACTER_JA = "qwen-plus-character-ja"
    QWEN_PLUS_LATEST = "qwen-plus-latest"
    QWEN_TURBO = "qwen-turbo"
    QWEN_TURBO_2024_11_01 = "qwen-turbo-2024-11-01"
    QWEN_TURBO_2025_04_28 = "qwen-turbo-2025-04-28"
    QWEN_TURBO_LATEST = "qwen-turbo-latest"
    QWEN_VL_MAX = "qwen-vl-max"
    QWEN_VL_OCR = "qwen-vl-ocr"
    QWEN_VL_PLUS = "qwen-vl-plus"
    QWEN2_5_14B_INSTRUCT = "qwen2-5-14b-instruct"
    QWEN2_5_32B_INSTRUCT = "qwen2-5-32b-instruct"
    QWEN2_5_72B_INSTRUCT = "qwen2-5-72b-instruct"
    QWEN2_5_7B_INSTRUCT = "qwen2-5-7b-instruct"
    QWEN2_5_OMNI_7B = "qwen2-5-omni-7b"
    QWEN2_5_VL_72B_INSTRUCT = "qwen2-5-vl-72b-instruct"
    QWEN2_5_VL_7B_INSTRUCT = "qwen2-5-vl-7b-instruct"
    QWEN3_14B = "qwen3-14b"
    QWEN3_235B_A22B = "qwen3-235b-a22b"
    QWEN3_32B = "qwen3-32b"
    QWEN3_8B = "qwen3-8b"
    QWEN3_ASR_FLASH = "qwen3-asr-flash"
    QWEN3_CODER_30B_A3B_INSTRUCT = "qwen3-coder-30b-a3b-instruct"
    QWEN3_CODER_480B_A35B_INSTRUCT = "qwen3-coder-480b-a35b-instruct"
    QWEN3_CODER_FLASH = "qwen3-coder-flash"
    QWEN3_CODER_FLASH_2025_07_28 = "qwen3-coder-flash-2025-07-28"
    QWEN3_CODER_PLUS = "qwen3-coder-plus"
    QWEN3_CODER_PLUS_2025_07_22 = "qwen3-coder-plus-2025-07-22"
    QWEN3_LIVETRANSLATE_FLASH_REALTIME = "qwen3-livetranslate-flash-realtime"
    QWEN3_MAX = "qwen3-max"
    QWEN3_MAX_PREVIEW = "qwen3-max-preview"
    QWEN3_NEXT_80B_A3B_INSTRUCT = "qwen3-next-80b-a3b-instruct"
    QWEN3_NEXT_80B_A3B_THINKING = "qwen3-next-80b-a3b-thinking"
    QWEN3_OMNI_FLASH = "qwen3-omni-flash"
    QWEN3_OMNI_FLASH_REALTIME = "qwen3-omni-flash-realtime"
    QWEN3_VL_235B_A22B = "qwen3-vl-235b-a22b"
    QWEN3_VL_30B_A3B = "qwen3-vl-30b-a3b"
    QWEN3_VL_PLUS = "qwen3-vl-plus"
    QWQ_PLUS = "qwq-plus"


# DeepBricksModels
class DeepBricksModels:
    """DeepBricksModels constants."""
    GPT_4O_2024_08_06 = "GPT-4o-2024-08-06"
    GPT_4O = "GPT-4o"
    GPT_4_TURBO = "GPT-4-turbo"
    CLAUDE_3_5_SONNET = "Claude-3.5-Sonnet"
    GPT_4O_MINI = "GPT-4o-mini"
    GPT_3_5_TURBO = "GPT-3.5-turbo"
    GPT_3_5_TURBO_INSTRUCT = "GPT-3.5-turbo-instruct"
    LLAMA_3_1_405B = "LLama-3.1-405b"
    LLAMA_3_1_70B = "LLama-3.1-70b"
    LLAMA_3_70B = "LLama-3-70b"


# DeepInfraModels
class DeepInfraModels:
    """DeepInfraModels constants."""
    META_LLAMA_META_LLAMA_3_3_70B_INSTRUCT = "meta-llama/Meta-Llama-3.3-70B-Instruct"
    META_LLAMA_META_LLAMA_3_3_70B_INSTRUCT_TURBO = "meta-llama/Meta-Llama-3.3-70B-Instruct-Turbo"
    MICROSOFT_WIZARDLM_2_8X22B = "microsoft/WizardLM-2-8x22B"
    MISTRALAI_MIXTRAL_8X7B_INSTRUCT_V0_1 = "mistralai/Mixtral-8x7B-Instruct-v0.1"
    META_LLAMA_META_LLAMA_3_1_8B_INSTRUCT = "meta-llama/Meta-Llama-3.1-8B-Instruct"
    OPENCHAT_OPENCHAT_3_5 = "openchat/openchat_3.5"
    META_LLAMA_META_LLAMA_3_8B_INSTRUCT = "meta-llama/Meta-Llama-3-8B-Instruct"
    MISTRALAI_MISTRAL_7B_INSTRUCT_V0_3 = "mistralai/Mistral-7B-Instruct-v0.3"
    MICROSOFT_WIZARDLM_2_7B = "microsoft/WizardLM-2-7B"
    GRYPHE_MYTHOMAX_L2_13B = "Gryphe/MythoMax-L2-13b"
    META_LLAMA_META_LLAMA_3_1_70B_INSTRUCT = "meta-llama/Meta-Llama-3.1-70B-Instruct"
    META_LLAMA_META_LLAMA_3_70B_INSTRUCT = "meta-llama/Meta-Llama-3-70B-Instruct"
    META_LLAMA_META_LLAMA_3_1_405B_INSTRUCT = "meta-llama/Meta-Llama-3.1-405B-Instruct"
    LIZPRECIATIOR_LZLV_70B_FP16_HF = "lizpreciatior/lzlv_70b_fp16_hf"
    DEEPSEEK_AI_DEEPSEEK_R1_0528 = "deepseek-ai/DeepSeek-R1-0528"
    QWEN_QWEN_IMAGE_EDIT = "Qwen/Qwen-Image-Edit"
    BRIA_FIBO = "Bria/fibo"
    BRIA_REPLACE_BACKGROUND = "Bria/replace_background"
    BRIA_BLUR_BACKGROUND = "Bria/blur_background"
    SENTENCE_TRANSFORMERS_CLIP_VIT_B_32_MULTILINGUAL_V1 = "sentence-transformers/clip-ViT-B-32-multilingual-v1"
    BLACK_FOREST_LABS_FLUX_1_DEV = "black-forest-labs/FLUX-1-dev"
    ANTHROPIC_CLAUDE_4_SONNET = "anthropic/claude-4-sonnet"
    DEEPSEEK_AI_DEEPSEEK_V3_0324 = "deepseek-ai/DeepSeek-V3-0324"
    BLACK_FOREST_LABS_FLUX_1_SCHNELL = "black-forest-labs/FLUX-1-schnell"
    MOONSHOTAI_KIMI_K2_THINKING = "moonshotai/Kimi-K2-Thinking"
    GOOGLE_GEMMA_3_4B_IT = "google/gemma-3-4b-it"
    PRUNAAI_P_IMAGE_EDIT = "PrunaAI/p-image-Edit"
    QWEN_QWEN3_VL_30B_A3B_INSTRUCT = "Qwen/Qwen3-VL-30B-A3B-Instruct"
    THENLPER_GTE_LARGE = "thenlper/gte-large"
    BLACK_FOREST_LABS_FLUX_1_1_PRO = "black-forest-labs/FLUX-1.1-pro"
    ANTHROPIC_CLAUDE_3_7_SONNET_LATEST = "anthropic/claude-3-7-sonnet-latest"
    OPENAI_GPT_OSS_20B = "openai/gpt-oss-20b"
    META_LLAMA_LLAMA_GUARD_4_12B = "meta-llama/Llama-Guard-4-12B"
    BRIA_BRIA_3_2 = "Bria/Bria-3.2"
    BRIA_REMOVE_BACKGROUND = "Bria/remove_background"
    QWEN_QWEN3_VL_235B_A22B_INSTRUCT = "Qwen/Qwen3-VL-235B-A22B-Instruct"
    QWEN_QWEN3_EMBEDDING_0_6B = "Qwen/Qwen3-Embedding-0.6B"
    GOOGLE_GEMINI_2_0_FLASH_001 = "google/gemini-2.0-flash-001"
    QWEN_QWEN3_CODER_480B_A35B_INSTRUCT = "Qwen/Qwen3-Coder-480B-A35B-Instruct"
    MISTRALAI_MISTRAL_SMALL_3_2_24B_INSTRUCT_2506 = "mistralai/Mistral-Small-3.2-24B-Instruct-2506"
    DEEPSEEK_AI_DEEPSEEK_V3_1_TERMINUS = "deepseek-ai/DeepSeek-V3.1-Terminus"
    ALLENAI_OLMOCR_2_7B_1025 = "allenai/olmOCR-2-7B-1025"
    BRIA_ENHANCE = "Bria/enhance"
    BLACK_FOREST_LABS_FLUX_1_KONTEXT_DEV = "black-forest-labs/FLUX.1-Kontext-dev"
    STABILITYAI_SDXL_TURBO = "stabilityai/sdxl-turbo"
    META_LLAMA_LLAMA_3_2_11B_VISION_INSTRUCT = "meta-llama/Llama-3.2-11B-Vision-Instruct"
    BLACK_FOREST_LABS_FLUX_PRO = "black-forest-labs/FLUX-pro"
    META_LLAMA_LLAMA_4_SCOUT_17B_16E_INSTRUCT = "meta-llama/Llama-4-Scout-17B-16E-Instruct"
    SAO10K_L3_8B_LUNARIS_V1_TURBO = "Sao10K/L3-8B-Lunaris-v1-Turbo"
    QWEN_QWEN2_5_72B_INSTRUCT = "Qwen/Qwen2.5-72B-Instruct"
    SENTENCE_TRANSFORMERS_ALL_MPNET_BASE_V2 = "sentence-transformers/all-mpnet-base-v2"
    INTFLOAT_MULTILINGUAL_E5_LARGE = "intfloat/multilingual-e5-large"
    SENTENCE_TRANSFORMERS_CLIP_VIT_B_32 = "sentence-transformers/clip-ViT-B-32"
    META_LLAMA_META_LLAMA_3_1_8B_INSTRUCT_TURBO = "meta-llama/Meta-Llama-3.1-8B-Instruct-Turbo"
    QWEN_QWEN2_5_VL_32B_INSTRUCT = "Qwen/Qwen2.5-VL-32B-Instruct"
    DEEPSEEK_AI_DEEPSEEK_R1_0528_TURBO = "deepseek-ai/DeepSeek-R1-0528-Turbo"
    MOONSHOTAI_KIMI_K2_INSTRUCT_0905 = "moonshotai/Kimi-K2-Instruct-0905"
    NOUSRESEARCH_HERMES_3_LLAMA_3_1_70B = "NousResearch/Hermes-3-Llama-3.1-70B"
    SENTENCE_TRANSFORMERS_ALL_MINILM_L12_V2 = "sentence-transformers/all-MiniLM-L12-v2"
    QWEN_QWEN3_EMBEDDING_8B_BATCH = "Qwen/Qwen3-Embedding-8B-batch"
    BYTEDANCE_SEEDREAM_4 = "ByteDance/Seedream-4"
    GOOGLE_GEMINI_2_5_FLASH = "google/gemini-2.5-flash"
    GOOGLE_GEMINI_2_5_PRO = "google/gemini-2.5-pro"
    SENTENCE_TRANSFORMERS_PARAPHRASE_MINILM_L6_V2 = "sentence-transformers/paraphrase-MiniLM-L6-v2"
    QWEN_QWEN3_EMBEDDING_4B = "Qwen/Qwen3-Embedding-4B"
    BLACK_FOREST_LABS_FLUX_2_PRO = "black-forest-labs/FLUX-2-pro"
    MICROSOFT_PHI_4 = "microsoft/phi-4"
    OPENAI_GPT_OSS_120B_TURBO = "openai/gpt-oss-120b-Turbo"
    QWEN_QWEN3_CODER_480B_A35B_INSTRUCT_TURBO = "Qwen/Qwen3-Coder-480B-A35B-Instruct-Turbo"
    META_LLAMA_LLAMA_4_MAVERICK_17B_128E_INSTRUCT_FP8 = "meta-llama/Llama-4-Maverick-17B-128E-Instruct-FP8"
    QWEN_QWEN3_235B_A22B_THINKING_2507 = "Qwen/Qwen3-235B-A22B-Thinking-2507"
    DEEPSEEK_AI_JANUS_PRO_1B = "deepseek-ai/Janus-Pro-1B"
    GOOGLE_GEMINI_1_5_FLASH_8B = "google/gemini-1.5-flash-8b"
    QWEN_QWEN3_NEXT_80B_A3B_INSTRUCT = "Qwen/Qwen3-Next-80B-A3B-Instruct"
    INTFLOAT_MULTILINGUAL_E5_LARGE_INSTRUCT = "intfloat/multilingual-e5-large-instruct"
    BAAI_BGE_M3_MULTI = "BAAI/bge-m3-multi"
    QWEN_QWEN3_14B = "Qwen/Qwen3-14B"
    GOOGLE_GEMINI_1_5_FLASH = "google/gemini-1.5-flash"
    META_LLAMA_LLAMA_3_3_70B_INSTRUCT_TURBO = "meta-llama/Llama-3.3-70B-Instruct-Turbo"
    DEEPSEEK_AI_JANUS_PRO_7B = "deepseek-ai/Janus-Pro-7B"
    QWEN_QWEN3_EMBEDDING_4B_BATCH = "Qwen/Qwen3-Embedding-4B-batch"
    THENLPER_GTE_BASE = "thenlper/gte-base"
    BRIA_ERASE = "Bria/erase"
    MINIMAXAI_MINIMAX_M2 = "MiniMaxAI/MiniMax-M2"
    BRIA_GEN_FILL = "Bria/gen_fill"
    GOOGLE_GEMMA_3_12B_IT = "google/gemma-3-12b-it"
    BLACK_FOREST_LABS_FLUX_1_REDUX_DEV = "black-forest-labs/FLUX-1-Redux-dev"
    BRIA_ERASE_FOREGROUND = "Bria/erase_foreground"
    QWEN_QWEN3_235B_A22B_INSTRUCT_2507 = "Qwen/Qwen3-235B-A22B-Instruct-2507"
    BAAI_BGE_LARGE_EN_V1_5 = "BAAI/bge-large-en-v1.5"
    SHIBING624_TEXT2VEC_BASE_CHINESE = "shibing624/text2vec-base-chinese"
    DEEPSEEK_AI_DEEPSEEK_V3 = "deepseek-ai/DeepSeek-V3"
    DEEPSEEK_AI_DEEPSEEK_V3_1 = "deepseek-ai/DeepSeek-V3.1"
    META_LLAMA_LLAMA_3_2_3B_INSTRUCT = "meta-llama/Llama-3.2-3B-Instruct"
    PADDLEPADDLE_PADDLEOCR_VL_0_9B = "PaddlePaddle/PaddleOCR-VL-0.9B"
    BRIA_BRIA_3_2_VECTOR = "Bria/Bria-3.2-vector"
    QWEN_QWEN3_EMBEDDING_0_6B_BATCH = "Qwen/Qwen3-Embedding-0.6B-batch"
    META_LLAMA_META_LLAMA_3_1_70B_INSTRUCT_TURBO = "meta-llama/Meta-Llama-3.1-70B-Instruct-Turbo"
    OPENAI_GPT_OSS_120B = "openai/gpt-oss-120b"
    ZAI_ORG_GLM_4_6 = "zai-org/GLM-4.6"
    INTFLOAT_E5_LARGE_V2 = "intfloat/e5-large-v2"
    NVIDIA_LLAMA_3_1_NEMOTRON_70B_INSTRUCT = "nvidia/Llama-3.1-Nemotron-70B-Instruct"
    PRUNAAI_P_IMAGE = "PrunaAI/p-image"
    BRIA_EXPAND = "Bria/expand"
    BAAI_BGE_EN_ICL = "BAAI/bge-en-icl"
    SAO10K_L3_3_70B_EURYALE_V2_3 = "Sao10K/L3.3-70B-Euryale-v2.3"
    SAO10K_L3_1_70B_EURYALE_V2_2 = "Sao10K/L3.1-70B-Euryale-v2.2"
    DEEPSEEK_AI_DEEPSEEK_R1_DISTILL_LLAMA_70B = "deepseek-ai/DeepSeek-R1-Distill-Llama-70B"
    QWEN_QWEN3_EMBEDDING_8B = "Qwen/Qwen3-Embedding-8B"
    SENTENCE_TRANSFORMERS_ALL_MINILM_L6_V2 = "sentence-transformers/all-MiniLM-L6-v2"
    SENTENCE_TRANSFORMERS_MULTI_QA_MPNET_BASE_DOT_V1 = "sentence-transformers/multi-qa-mpnet-base-dot-v1"
    NVIDIA_LLAMA_3_3_NEMOTRON_SUPER_49B_V1_5 = "nvidia/Llama-3.3-Nemotron-Super-49B-v1.5"
    NOUSRESEARCH_HERMES_3_LLAMA_3_1_405B = "NousResearch/Hermes-3-Llama-3.1-405B"
    DEEPSEEK_AI_DEEPSEEK_OCR = "deepseek-ai/DeepSeek-OCR"
    BAAI_BGE_BASE_EN_V1_5 = "BAAI/bge-base-en-v1.5"
    QWEN_QWEN3_30B_A3B = "Qwen/Qwen3-30B-A3B"
    INTFLOAT_E5_BASE_V2 = "intfloat/e5-base-v2"
    GOOGLE_GEMMA_3_27B_IT = "google/gemma-3-27b-it"
    GOOGLE_EMBEDDINGGEMMA_300M = "google/embeddinggemma-300m"
    MISTRALAI_MISTRAL_NEMO_INSTRUCT_2407 = "mistralai/Mistral-Nemo-Instruct-2407"
    QWEN_QWEN3_32B = "Qwen/Qwen3-32B"
    MISTRALAI_MISTRAL_SMALL_24B_INSTRUCT_2501 = "mistralai/Mistral-Small-24B-Instruct-2501"
    NVIDIA_NVIDIA_NEMOTRON_NANO_12B_V2_VL = "nvidia/NVIDIA-Nemotron-Nano-12B-v2-VL"
    BLACK_FOREST_LABS_FLUX_2_DEV = "black-forest-labs/FLUX-2-dev"
    BAAI_BGE_M3 = "BAAI/bge-m3"
    NVIDIA_NVIDIA_NEMOTRON_NANO_9B_V2 = "nvidia/NVIDIA-Nemotron-Nano-9B-v2"
    ANTHROPIC_CLAUDE_4_OPUS = "anthropic/claude-4-opus"


# DeepSeekModels
class DeepSeekModels:
    """DeepSeekModels constants."""
    DEEPSEEK_CHAT = "deepseek-chat"
    DEEPSEEK_REASONER = "deepseek-reasoner"


# DeepgramModels
class DeepgramModels:
    """DeepgramModels constants."""
    FLUX = "flux"
    NOVA_3_MONOLINGUAL = "nova-3-monolingual"
    NOVA_3_MULTILINGUAL = "nova-3-multilingual"
    NOVA_1 = "nova-1"
    NOVA_2 = "nova-2"
    GROWTH_NOVA_3_MONOLINGUAL = "growth-nova-3-monolingual"
    GROWTH_NOVA_3_MULTILINGUAL = "growth-nova-3-multilingual"
    GROWTH_NOVA_1 = "growth-nova-1"
    GROWTH_NOVA_2 = "growth-nova-2"
    ENHANCED = "enhanced"
    BASE = "base"
    REDACTION = "redaction"
    KEYTERM_PROMPTING = "keyterm-prompting"
    SPEAKER_DIARIZATION = "speaker-diarization"
    AURA_2 = "aura-2"
    AURA_1 = "aura-1"
    GROWTH_AURA_2 = "growth-aura-2"
    GROWTH_AURA_1 = "growth-aura-1"


# ElevenLabsModels
class ElevenLabsModels:
    """ElevenLabsModels constants."""
    BUSINESS_SCRIBE_V1_V2 = "business-scribe-v1-v2"
    BUSINESS_MULTILINGUAL_V2_V3 = "business-multilingual-v2-v3"


# FireworksAIModels
class FireworksAIModels:
    """FireworksAIModels constants."""
    MIXTRAL_8X7B = "mixtral-8x7b"
    MIXTRAL_8X22B_INSTRUCT = "mixtral-8x22b-instruct"
    DBRX_INSTRUCT = "dbrx-instruct"
    MODEL_4B = "4b"
    MODEL_16B = "16b"
    MODEL_100B = "100b"
    NOMIC_AI_NOMIC_EMBED_TEXT_V1_5 = "nomic-ai/nomic-embed-text-v1.5"
    NOMIC_AI_NOMIC_EMBED_TEXT_V1 = "nomic-ai/nomic-embed-text-v1"
    THENLPER_GTE_BASE = "thenlper/gte-base"
    WHEREISAI_UAE_LARGE_V1 = "WhereIsAI/UAE-Large-V1"
    THENLPER_GTE_LARGE = "thenlper/gte-large"
    LLAMA_V3P1_405B_INSTRUCT = "llama-v3p1-405b-instruct"
    DEEPSEEK_R1 = "deepseek-r1"
    DEEPSEEK_V3 = "deepseek-v3"
    LLAMA4_SCOUT_INSTRUCT_BASIC = "llama4-scout-instruct-basic"
    LLAMA4_MAVERICK_INSTRUCT_BASIC = "llama4-maverick-instruct-basic"
    KIMI_K2_INSTRUCT_0905 = "kimi-k2-instruct-0905"
    KIMI_K2_INSTRUCT = "kimi-k2-instruct"
    KIMI_K2_THINKING = "kimi-k2-thinking"


# GoogleCloudSpeechSTTModels
class GoogleCloudSpeechSTTModels:
    """GoogleCloudSpeechSTTModels constants."""
    GOOGLE_STANDARD = "google-standard"


# GoogleCloudTTSTTSModels
class GoogleCloudTTSTTSModels:
    """GoogleCloudTTSTTSModels constants."""
    CHIRP_3_HD = "chirp-3-hd"
    GOOGLE_INSTANT_CUSTOM = "google-instant-custom"
    WAVENET = "wavenet"
    STUDIO = "studio"
    GOOGLE_STANDARD = "google-standard"
    NEURAL2 = "neural2"
    POLYGLOT_PREVIEW = "polyglot-preview"


# GoogleModels
class GoogleModels:
    """GoogleModels constants."""
    GEMINI_PRO = "gemini-pro"
    GEMINI_PRO_VISION = "gemini-pro-vision"
    EMBEDDING_001 = "embedding-001"
    GEMINI_1_5_FLASH_LATEST_GT_128K = "gemini-1.5-flash-latest-gt-128k"
    GEMINI_1_5_FLASH_LATEST_LTE_128K = "gemini-1.5-flash-latest-lte-128k"
    GEMINI_1_5_FLASH_GT_128K = "gemini-1.5-flash-gt-128k"
    GEMINI_1_5_FLASH_LTE_128K = "gemini-1.5-flash-lte-128k"
    GEMINI_1_5_PRO_LATEST_GT_128K = "gemini-1.5-pro-latest-gt-128k"
    GEMINI_1_5_PRO_LATEST_LTE_128K = "gemini-1.5-pro-latest-lte-128k"
    GEMINI_1_5_PRO_GT_128K = "gemini-1.5-pro-gt-128k"
    GEMINI_1_5_PRO_LTE_128K = "gemini-1.5-pro-lte-128k"
    GEMINI_1_5_FLASH_001_LTE_128K = "gemini-1.5-flash-001-lte-128k"
    GEMINI_1_5_FLASH_001_GT_128K = "gemini-1.5-flash-001-gt-128k"
    GEMINI_1_5_FLASH_002_LTE_128K = "gemini-1.5-flash-002-lte-128k"
    GEMINI_1_5_FLASH_002_GT_128K = "gemini-1.5-flash-002-gt-128k"
    GEMINI_1_5_PRO_001_GT_128K = "gemini-1.5-pro-001-gt-128k"
    GEMINI_1_5_PRO_001_LTE_128K = "gemini-1.5-pro-001-lte-128k"
    GEMINI_1_5_PRO_002_GT_128K = "gemini-1.5-pro-002-gt-128k"
    GEMINI_1_5_PRO_002_LTE_128K = "gemini-1.5-pro-002-lte-128k"
    GEMINI_1_5_FLASH_8B_LTE_128K = "gemini-1.5-flash-8b-lte-128k"
    GEMINI_1_5_FLASH_8B_GT_128K = "gemini-1.5-flash-8b-gt-128k"
    GEMINI_1_5_FLASH_8B_001_LTE_128K = "gemini-1.5-flash-8b-001-lte-128k"
    GEMINI_1_5_FLASH_8B_001_GT_128K = "gemini-1.5-flash-8b-001-gt-128k"
    GEMINI_1_5_FLASH_8B_LATEST_LTE_128K = "gemini-1.5-flash-8b-latest-lte-128k"
    GEMINI_1_5_FLASH_8B_LATEST_GT_128K = "gemini-1.5-flash-8b-latest-gt-128k"
    GEMINI_2_0_FLASH_001 = "gemini-2.0-flash-001"
    GEMINI_2_0_FLASH_LTE_128K = "gemini-2.0-flash-lte-128k"
    GEMINI_2_0_FLASH_GT_128K = "gemini-2.0-flash-gt-128k"
    GEMINI_2_0_FLASH_LITE_001 = "gemini-2.0-flash-lite-001"
    GEMINI_2_0_FLASH_LITE_LTE_128K = "gemini-2.0-flash-lite-lte-128k"
    GEMINI_2_0_FLASH_LITE_GT_128K = "gemini-2.0-flash-lite-gt-128k"
    GEMINI_2_0_FLASH_LITE = "gemini-2.0-flash-lite"
    GEMINI_2_5_PRO_LTE_128K = "gemini-2.5-pro-lte-128k"
    GEMINI_2_5_PRO_GT_128K = "gemini-2.5-pro-gt-128k"
    GEMINI_2_5_PRO_PREVIEW_03_25_LTE_128K = "gemini-2.5-pro-preview-03-25-lte-128k"
    GEMINI_2_5_PRO_PREVIEW_03_25_GT_128K = "gemini-2.5-pro-preview-03-25-gt-128k"
    GEMINI_2_5_PRO_PREVIEW_05_06_LTE_128K = "gemini-2.5-pro-preview-05-06-lte-128k"
    GEMINI_2_5_PRO_PREVIEW_05_06_GT_128K = "gemini-2.5-pro-preview-05-06-gt-128k"
    GEMINI_2_5_FLASH_PREVIEW_04_17_LTE_128K = "gemini-2.5-flash-preview-04-17-lte-128k"
    GEMINI_2_5_FLASH_PREVIEW_04_17_GT_128K = "gemini-2.5-flash-preview-04-17-gt-128k"
    GEMINI_3_PRO_PREVIEW_LTE_128K = "gemini-3-pro-preview-lte-128k"
    GEMINI_3_PRO_PREVIEW_GT_128K = "gemini-3-pro-preview-gt-128k"
    GEMINI_3_PRO_PREVIEW_02_05_LTE_128K = "gemini-3-pro-preview-02-05-lte-128k"
    GEMINI_3_PRO_PREVIEW_02_05_GT_128K = "gemini-3-pro-preview-02-05-gt-128k"
    GEMINI_2_5_FLASH_PREVIEW_05_20_GT_128K = "gemini-2.5-flash-preview-05-20-gt-128k"
    GEMINI_2_5_FLASH_PREVIEW_05_20_LTE_128K = "gemini-2.5-flash-preview-05-20-lte-128k"
    GEMINI_2_5_FLASH_LITE_PREVIEW_06_17_GT_128K = "gemini-2.5-flash-lite-preview-06-17-gt-128k"
    GEMINI_2_5_FLASH_LITE_PREVIEW_06_17_LTE_128K = "gemini-2.5-flash-lite-preview-06-17-lte-128k"
    GEMINI_2_5_FLASH_LTE_128K = "gemini-2.5-flash-lte-128k"
    GEMINI_2_5_FLASH_GT_128K = "gemini-2.5-flash-gt-128k"
    GEMINI_2_5_FLASH_LITE = "gemini-2.5-flash-lite"
    GEMINI_2_0_FLASH_EXP_001_GT_128K = "gemini-2.0-flash-exp-001-gt-128k"
    GEMINI_2_0_FLASH_EXP_001_LTE_128K = "gemini-2.0-flash-exp-001-lte-128k"
    GEMINI_2_5_FLASH_IMAGE_LTE_128K = "gemini-2.5-flash-image-lte-128k"
    GEMINI_2_5_FLASH_IMAGE_GT_128K = "gemini-2.5-flash-image-gt-128k"
    GEMINI_3_PRO_IMAGE_PREVIEW_LTE_128K = "gemini-3-pro-image-preview-lte-128k"
    GEMINI_3_PRO_IMAGE_PREVIEW_GT_128K = "gemini-3-pro-image-preview-gt-128k"
    GEMINI_EMBEDDING_001 = "gemini-embedding-001"
    GEMINI_2_5_FLASH_LITE_LTE_128K = "gemini-2.5-flash-lite-lte-128k"
    GEMINI_2_5_FLASH_LITE_GT_128K = "gemini-2.5-flash-lite-gt-128k"
    GEMINI_2_5_FLASH_LITE_PREVIEW_09_2025_LTE_128K = "gemini-2.5-flash-lite-preview-09-2025-lte-128k"
    GEMINI_2_5_FLASH_LITE_PREVIEW_09_2025_GT_128K = "gemini-2.5-flash-lite-preview-09-2025-gt-128k"
    GEMINI_2_5_FLASH_PREVIEW_09_2025_LTE_128K = "gemini-2.5-flash-preview-09-2025-lte-128k"
    GEMINI_2_5_FLASH_PREVIEW_09_2025_GT_128K = "gemini-2.5-flash-preview-09-2025-gt-128k"
    GEMINI_FLASH_LATEST_LTE_128K = "gemini-flash-latest-lte-128k"
    GEMINI_FLASH_LATEST_GT_128K = "gemini-flash-latest-gt-128k"
    GEMINI_FLASH_LITE_LATEST_LTE_128K = "gemini-flash-lite-latest-lte-128k"
    GEMINI_FLASH_LITE_LATEST_GT_128K = "gemini-flash-lite-latest-gt-128k"
    GEMINI_2_5_FLASH_IMAGE_PREVIEW_LTE_128K = "gemini-2.5-flash-image-preview-lte-128k"
    GEMINI_2_5_FLASH_IMAGE_PREVIEW_GT_128K = "gemini-2.5-flash-image-preview-gt-128k"
    GEMINI_3_FLASH_PREVIEW_LTE_128K = "gemini-3-flash-preview-lte-128k"
    GEMINI_3_FLASH_PREVIEW_GT_128K = "gemini-3-flash-preview-gt-128k"


# GroqModels
class GroqModels:
    """GroqModels constants."""
    LLAMA2_70B_4096 = "llama2-70b-4096"
    MIXTRAL_8X7B_32768 = "mixtral-8x7b-32768"
    LLAMA3_8B_8192 = "llama3-8b-8192"
    LLAMA3_70B_8192 = "llama3-70b-8192"
    GEMMA_7B_IT = "gemma-7b-it"
    GEMMA2_9B_IT = "gemma2-9b-it"
    LLAMA3_GROQ_70B_8192_TOOL_USE_PREVIEW = "llama3-groq-70b-8192-tool-use-preview"
    LLAMA3_GROQ_8B_8192_TOOL_USE_PREVIEW = "llama3-groq-8b-8192-tool-use-preview"
    LLAMA_3_1_70B_VERSATILE = "llama-3.1-70b-versatile"
    LLAMA_3_1_8B_INSTANT = "llama-3.1-8b-instant"
    LLAMA_GUARD_3_8B = "llama-guard-3-8b"
    DEEPSEEK_R1_DISTILL_LLAMA_70B = "deepseek-r1-distill-llama-70b"
    META_LLAMA_LLAMA_4_MAVERICK_17B_128E_INSTRUCT = "meta-llama/llama-4-maverick-17b-128e-instruct"
    META_LLAMA_LLAMA_4_SCOUT_17B_16E_INSTRUCT = "meta-llama/llama-4-scout-17b-16e-instruct"
    OPENAI_GPT_OSS_120B = "openai/gpt-oss-120b"
    OPENAI_GPT_OSS_20B = "openai/gpt-oss-20b"
    OPENAI_GPT_OSS_SAFEGUARD_20B = "openai/gpt-oss-safeguard-20b"
    MOONSHOTAI_KIMI_K2_INSTRUCT_0905 = "moonshotai/kimi-k2-instruct-0905"
    META_LLAMA_LLAMA_GUARD_4_12B = "meta-llama/llama-guard-4-12b"
    QWEN_QWEN3_32B = "qwen/qwen3-32b"
    LLAMA_3_3_70B_VERSATILE = "llama-3.3-70b-versatile"


# JinaModels
class JinaModels:
    """JinaModels constants."""
    JINA_EMBEDDINGS_V2_BASE_EN = "jina-embeddings-v2-base-en"
    JINA_EMBEDDINGS_V2_BASE_CODE = "jina-embeddings-v2-base-code"
    JINA_EMBEDDINGS_V2_BASE_ZH = "jina-embeddings-v2-base-zh"
    JINA_COLBERT_V1_EN = "jina-colbert-v1-en"
    JINA_EMBEDDINGS_V2_BASE_DE = "jina-embeddings-v2-base-de"
    JINA_EMBEDDINGS_V2_BASE_ES = "jina-embeddings-v2-base-es"
    JINA_RERANKER_V1_BASE_EN = "jina-reranker-v1-base-en"
    JINA_COLBERT_V2 = "jina-colbert-v2"
    JINA_RERANKER_V2_BASE_MULTILINGUAL = "jina-reranker-v2-base-multilingual"
    JINA_RERANKER_V3 = "jina-reranker-v3"


# MistralAIModels
class MistralAIModels:
    """MistralAIModels constants."""
    MISTRAL_TINY = "mistral-tiny"
    MISTRAL_SMALL = "mistral-small"
    MISTRAL_MEDIUM = "mistral-medium"
    MISTRAL_EMBED = "mistral-embed"
    OPEN_MISTRAL_7B = "open-mistral-7b"
    OPEN_MIXTRAL_8X7B = "open-mixtral-8x7b"
    OPEN_MIXTRAL_8X22B = "open-mixtral-8x22b"
    MISTRAL_SMALL_LATEST = "mistral-small-latest"
    MAGISTRAL_MEDIUM_LATEST = "magistral-medium-latest"
    MAGISTRAL_SMALL_LATEST = "magistral-small-latest"
    MISTRAL_MEDIUM_LATEST = "mistral-medium-latest"
    MISTRAL_LARGE_LATEST = "mistral-large-latest"


# MonsterAPIModels
class MonsterAPIModels:
    """MonsterAPIModels constants."""
    TINYLLAMA_TINYLLAMA_1_1B_CHAT_V1_0 = "TinyLlama/TinyLlama-1.1B-Chat-v1.0"
    MICROSOFT_PHI_2 = "microsoft/phi-2"
    HUGGINGFACEH4_ZEPHYR_7B_BETA = "HuggingFaceH4/zephyr-7b-beta"
    MISTRALAI_MISTRAL_7B_INSTRUCT_V0_2 = "mistralai/Mistral-7B-Instruct-v0.2"


# NebiusModels
class NebiusModels:
    """NebiusModels constants."""
    DEEPSEEK_AI_DEEPSEEK_R1_0528 = "deepseek-ai/DeepSeek-R1-0528"


# NomicModels
class NomicModels:
    """NomicModels constants."""
    NOMIC_EMBED_TEXT_V1 = "nomic-embed-text-v1"


# NovitaAIModels
class NovitaAIModels:
    """NovitaAIModels constants."""
    META_LLAMA_LLAMA_3_8B_INSTRUCT = "meta-llama/llama-3-8b-instruct"
    NOUSRESEARCH_NOUS_HERMES_LLAMA2_13B = "nousresearch/nous-hermes-llama2-13b"
    GRYPHE_MYTHOMAX_L2_13B = "gryphe/mythomax-l2-13b"
    NOUS_HERMES_2_MIXTRAL_8X7B_DPO = "Nous-Hermes-2-Mixtral-8x7B-DPO"
    LZLV_70B = "lzlv_70b"
    META_LLAMA_LLAMA_3_70B_INSTRUCT = "meta-llama/llama-3-70b-instruct"
    TEKNIUM_OPENHERMES_2_5_MISTRAL_7B = "teknium/openhermes-2.5-mistral-7b"
    MICROSOFT_WIZARDLM_2_8X22B = "microsoft/wizardlm-2-8x22b"


# OpenAIModels
class OpenAIModels:
    """OpenAIModels constants."""
    GPT_4_TURBO_PREVIEW = "gpt-4-turbo-preview"
    GPT_4_0125_PREVIEW = "gpt-4-0125-preview"
    GPT_4_TURBO = "gpt-4-turbo"
    GPT_4_TURBO_2024_04_09 = "gpt-4-turbo-2024-04-09"
    GPT_4 = "gpt-4"
    GPT_4_0613 = "gpt-4-0613"
    GPT_4_0314 = "gpt-4-0314"
    GPT_4_1106_PREVIEW = "gpt-4-1106-preview"
    GPT_4_1106_VISION_PREVIEW = "gpt-4-1106-vision-preview"
    GPT_4_32K = "gpt-4-32k"
    GPT_4_32K_0613 = "gpt-4-32k-0613"
    GPT_4_32K_0314 = "gpt-4-32k-0314"
    GPT_4_VISION_PREVIEW = "gpt-4-vision-preview"
    GPT_3_5_TURBO = "gpt-3.5-turbo"
    GPT_3_5_TURBO_1106 = "gpt-3.5-turbo-1106"
    GPT_3_5_TURBO_0125 = "gpt-3.5-turbo-0125"
    GPT_3_5_TURBO_16K = "gpt-3.5-turbo-16k"
    GPT_3_5_TURBO_INSTRUCT = "gpt-3.5-turbo-instruct"
    TEXT_EMBEDDING_ADA_002_V2 = "text-embedding-ada-002-v2"
    TEXT_EMBEDDING_ADA_002 = "text-embedding-ada-002"
    TEXT_EMBEDDING_3_SMALL = "text-embedding-3-small"
    TEXT_EMBEDDING_3_LARGE = "text-embedding-3-large"
    TEXT_MODERATION_004 = "text-moderation-004"
    DALL_E_3 = "dall-e-3"
    DALL_E_2 = "dall-e-2"
    TEXT_MODERATION_LATEST = "text-moderation-latest"
    TEXT_MODERATION_STABLE = "text-moderation-stable"
    FT_GPT_3_5_TURBO = "ft:gpt-3.5-turbo"
    FT_GPT_3_5_TURBO_0613 = "ft:gpt-3.5-turbo-0613"
    FT_GPT_3_5_TURBO_1106 = "ft:gpt-3.5-turbo-1106"
    FT_GPT_3_5_TURBO_0125 = "ft:gpt-3.5-turbo-0125"
    FT_GPT_4O_MINI_2024_07_18 = "ft:gpt-4o-mini-2024-07-18"
    FT_GPT_4O_2024_08_06 = "ft:gpt-4o-2024-08-06"
    GPT_4O = "gpt-4o"
    GPT_4O_LATEST = "gpt-4o-latest"
    GPT_4O_2024_05_13 = "gpt-4o-2024-05-13"
    GPT_4O_2024_08_06 = "gpt-4o-2024-08-06"
    GPT_4O_MINI = "gpt-4o-mini"
    GPT_4O_MINI_2024_07_18 = "gpt-4o-mini-2024-07-18"
    O1_PREVIEW = "o1-preview"
    O1 = "o1"
    O1_2024_12_17 = "o1-2024-12-17"
    O1_PREVIEW_2024_09_12 = "o1-preview-2024-09-12"
    O1_MINI = "o1-mini"
    O1_MINI_2024_09_12 = "o1-mini-2024-09-12"
    GPT_4O_REALTIME_PREVIEW_2024_10_01 = "gpt-4o-realtime-preview-2024-10-01"
    GPT_4O_REALTIME_PREVIEW_2025_06_03 = "gpt-4o-realtime-preview-2025-06-03"
    GPT_4O_REALTIME_PREVIEW = "gpt-4o-realtime-preview"
    GPT_3_5_TURBO_0613 = "gpt-3.5-turbo-0613"
    GPT_3_5_TURBO_16K_0613 = "gpt-3.5-turbo-16k-0613"
    CHATGPT_4O_LATEST = "chatgpt-4o-latest"
    GPT_4O_2024_11_20 = "gpt-4o-2024-11-20"
    GPT_4O_AUDIO_PREVIEW = "gpt-4o-audio-preview"
    GPT_4O_AUDIO_PREVIEW_2024_10_01 = "gpt-4o-audio-preview-2024-10-01"
    ADA_V2 = "ada-v2"
    WHISPER_1 = "whisper-1"
    TTS_1 = "tts-1"
    TTS_1_HD = "tts-1-hd"
    GPT_4O_MINI_TTS = "gpt-4o-mini-tts"
    GPT_4O_TRANSCRIBE = "gpt-4o-transcribe"
    GPT_4O_MINI_TRANSCRIBE = "gpt-4o-mini-transcribe"
    O3_MINI_2025_01_31 = "o3-mini-2025-01-31"
    O3_MINI = "o3-mini"
    GPT_4_5_PREVIEW_2025_02_27 = "gpt-4.5-preview-2025-02-27"
    O1_PRO = "o1-pro"
    O1_PRO_2025_03_19 = "o1-pro-2025-03-19"
    COMPUTER_USE_PREVIEW = "computer-use-preview"
    COMPUTER_USE_PREVIEW_2025_03_11 = "computer-use-preview-2025-03-11"
    GPT_4_1_2025_04_14 = "gpt-4.1-2025-04-14"
    GPT_4_1 = "gpt-4.1"
    GPT_4_1_MINI_2025_04_14 = "gpt-4.1-mini-2025-04-14"
    GPT_4_1_MINI = "gpt-4.1-mini"
    GPT_4_1_NANO_2025_04_14 = "gpt-4.1-nano-2025-04-14"
    FT_GPT_4_1_NANO_2025_04_14 = "ft:gpt-4.1-nano-2025-04-14"
    GPT_4_1_NANO = "gpt-4.1-nano"
    O3 = "o3"
    O3_2025_04_16 = "o3-2025-04-16"
    O3_PRO = "o3-pro"
    O3_PRO_2025_06_10 = "o3-pro-2025-06-10"
    O4_MINI = "o4-mini"
    O4_MINI_2025_04_16 = "o4-mini-2025-04-16"
    FT_O4_MINI_2025_04_16 = "ft:o4-mini-2025-04-16"
    FT_GPT_4O = "ft:gpt-4o"
    FT_GPT_4O_MINI = "ft:gpt-4o-mini"
    FT_GPT_4_1_2025_04_14 = "ft:gpt-4.1-2025-04-14"
    FT_GPT_4_1 = "ft:gpt-4.1"
    FT_GPT_4_1_MINI_2025_04_14 = "ft:gpt-4.1-mini-2025-04-14"
    FT_GPT_4_1_MINI = "ft:gpt-4.1-mini"
    O3_DEEP_RESEARCH = "o3-deep-research"
    O3_DEEP_RESEARCH_2025_06_26 = "o3-deep-research-2025-06-26"
    O4_MINI_DEEP_RESEARCH_2025_06_26 = "o4-mini-deep-research-2025-06-26"
    O4_MINI_DEEP_RESEARCH = "o4-mini-deep-research"
    GPT_4O_MINI_REALTIME_PREVIEW = "gpt-4o-mini-realtime-preview"
    GPT_4O_MINI_REALTIME_PREVIEW_2024_12_17 = "gpt-4o-mini-realtime-preview-2024-12-17"
    GPT_4O_SEARCH_PREVIEW = "gpt-4o-search-preview"
    GPT_4O_SEARCH_PREVIEW_2025_03_11 = "gpt-4o-search-preview-2025-03-11"
    GPT_4O_MINI_SEARCH_PREVIEW_2025_03_11 = "gpt-4o-mini-search-preview-2025-03-11"
    GPT_4O_MINI_SEARCH_PREVIEW = "gpt-4o-mini-search-preview"
    CODEX_MINI_LATEST = "codex-mini-latest"
    GPT_5_2025_08_07 = "gpt-5-2025-08-07"
    GPT_5 = "gpt-5"
    GPT_5_MINI = "gpt-5-mini"
    GPT_5_MINI_2025_08_07 = "gpt-5-mini-2025-08-07"
    GPT_5_NANO = "gpt-5-nano"
    GPT_5_NANO_2025_08_07 = "gpt-5-nano-2025-08-07"
    GPT_5_CHAT_LATEST = "gpt-5-chat-latest"
    GPT_5_CODEX = "gpt-5-codex"
    GPT_4O_MINI_AUDIO_PREVIEW = "gpt-4o-mini-audio-preview"
    GPT_4O_MINI_AUDIO_PREVIEW_2024_12_17 = "gpt-4o-mini-audio-preview-2024-12-17"
    GPT_5_PRO = "gpt-5-pro"
    GPT_5_PRO_2025_10_06 = "gpt-5-pro-2025-10-06"
    GPT_REALTIME = "gpt-realtime"
    GPT_REALTIME_2025_08_28 = "gpt-realtime-2025-08-28"
    GPT_AUDIO = "gpt-audio"
    GPT_AUDIO_MINI = "gpt-audio-mini"
    GPT_IMAGE_1 = "gpt-image-1"
    SORA_2 = "sora-2"
    SORA_2_PRO = "sora-2-pro"
    GPT_5_1 = "gpt-5.1"
    GPT_5_1_2025_11_13 = "gpt-5.1-2025-11-13"
    GPT_5_1_CODEX = "gpt-5.1-codex"
    GPT_5_1_CODEX_MINI = "gpt-5.1-codex-mini"
    GPT_5_1_CHAT_LATEST = "gpt-5.1-chat-latest"
    GPT_5_SEARCH_API_2025_10_14 = "gpt-5-search-api-2025-10-14"
    GPT_5_SEARCH_API = "gpt-5-search-api"
    GPT_5_2 = "gpt-5.2"
    GPT_5_2_2025_12_11 = "gpt-5.2-2025-12-11"
    GPT_5_2_CHAT_LATEST = "gpt-5.2-chat-latest"
    GPT_5_2_PRO = "gpt-5.2-pro"
    GPT_5_2_PRO_2025_12_11 = "gpt-5.2-pro-2025-12-11"
    GPT_5_1_CODEX_MAX = "gpt-5.1-codex-max"
    GPT_REALTIME_MINI = "gpt-realtime-mini"
    GPT_4O_TRANSCRIBE_DIARIZE = "gpt-4o-transcribe-diarize"
    GPT_IMAGE_1_5 = "gpt-image-1.5"
    GPT_IMAGE_1_5_2025_12_16 = "gpt-image-1.5-2025-12-16"
    GPT_5_2_CODEX = "gpt-5.2-codex"


# OpenRouterModels
class OpenRouterModels:
    """OpenRouterModels constants."""
    OPENROUTER_BODYBUILDER = "openrouter/bodybuilder"
    AMAZON_NOVA_2_LITE_V1_FREE = "amazon/nova-2-lite-v1:free"
    AMAZON_NOVA_2_LITE_V1 = "amazon/nova-2-lite-v1"
    MISTRALAI_MINISTRAL_14B_2512 = "mistralai/ministral-14b-2512"
    MISTRALAI_MINISTRAL_8B_2512 = "mistralai/ministral-8b-2512"
    MISTRALAI_MINISTRAL_3B_2512 = "mistralai/ministral-3b-2512"
    MISTRALAI_MISTRAL_LARGE_2512 = "mistralai/mistral-large-2512"
    ARCEE_AI_TRINITY_MINI_FREE = "arcee-ai/trinity-mini:free"
    ARCEE_AI_TRINITY_MINI = "arcee-ai/trinity-mini"
    DEEPSEEK_DEEPSEEK_V3_2_SPECIALE = "deepseek/deepseek-v3.2-speciale"
    DEEPSEEK_DEEPSEEK_V3_2 = "deepseek/deepseek-v3.2"
    PRIME_INTELLECT_INTELLECT_3 = "prime-intellect/intellect-3"
    TNGTECH_TNG_R1T_CHIMERA_FREE = "tngtech/tng-r1t-chimera:free"
    TNGTECH_TNG_R1T_CHIMERA = "tngtech/tng-r1t-chimera"
    ANTHROPIC_CLAUDE_OPUS_4_5 = "anthropic/claude-opus-4.5"
    ALLENAI_OLMO_3_32B_THINK_FREE = "allenai/olmo-3-32b-think:free"
    ALLENAI_OLMO_3_7B_INSTRUCT = "allenai/olmo-3-7b-instruct"
    ALLENAI_OLMO_3_7B_THINK = "allenai/olmo-3-7b-think"
    GOOGLE_GEMINI_3_PRO_IMAGE_PREVIEW = "google/gemini-3-pro-image-preview"
    X_AI_GROK_4_1_FAST = "x-ai/grok-4.1-fast"
    GOOGLE_GEMINI_3_PRO_PREVIEW = "google/gemini-3-pro-preview"
    DEEPCOGITO_COGITO_V2_1_671B = "deepcogito/cogito-v2.1-671b"
    OPENAI_GPT_5_1 = "openai/gpt-5.1"
    OPENAI_GPT_5_1_CHAT = "openai/gpt-5.1-chat"
    OPENAI_GPT_5_1_CODEX = "openai/gpt-5.1-codex"
    OPENAI_GPT_5_1_CODEX_MINI = "openai/gpt-5.1-codex-mini"
    KWAIPILOT_KAT_CODER_PRO_FREE = "kwaipilot/kat-coder-pro:free"
    MOONSHOTAI_KIMI_LINEAR_48B_A3B_INSTRUCT = "moonshotai/kimi-linear-48b-a3b-instruct"
    MOONSHOTAI_KIMI_K2_THINKING = "moonshotai/kimi-k2-thinking"
    AMAZON_NOVA_PREMIER_V1 = "amazon/nova-premier-v1"
    PERPLEXITY_SONAR_PRO_SEARCH = "perplexity/sonar-pro-search"
    MISTRALAI_VOXTRAL_SMALL_24B_2507 = "mistralai/voxtral-small-24b-2507"
    OPENAI_GPT_OSS_SAFEGUARD_20B = "openai/gpt-oss-safeguard-20b"
    NVIDIA_NEMOTRON_NANO_12B_V2_VL_FREE = "nvidia/nemotron-nano-12b-v2-vl:free"
    NVIDIA_NEMOTRON_NANO_12B_V2_VL = "nvidia/nemotron-nano-12b-v2-vl"
    MINIMAX_MINIMAX_M2 = "minimax/minimax-m2"
    LIQUID_LFM2_8B_A1B = "liquid/lfm2-8b-a1b"
    LIQUID_LFM_2_2_6B = "liquid/lfm-2.2-6b"
    IBM_GRANITE_GRANITE_4_0_H_MICRO = "ibm-granite/granite-4.0-h-micro"
    DEEPCOGITO_COGITO_V2_PREVIEW_LLAMA_405B = "deepcogito/cogito-v2-preview-llama-405b"
    OPENAI_GPT_5_IMAGE_MINI = "openai/gpt-5-image-mini"
    ANTHROPIC_CLAUDE_HAIKU_4_5 = "anthropic/claude-haiku-4.5"
    QWEN_QWEN3_VL_8B_THINKING = "qwen/qwen3-vl-8b-thinking"
    QWEN_QWEN3_VL_8B_INSTRUCT = "qwen/qwen3-vl-8b-instruct"
    OPENAI_GPT_5_IMAGE = "openai/gpt-5-image"
    OPENAI_O3_DEEP_RESEARCH = "openai/o3-deep-research"
    OPENAI_O4_MINI_DEEP_RESEARCH = "openai/o4-mini-deep-research"
    NVIDIA_LLAMA_3_3_NEMOTRON_SUPER_49B_V1_5 = "nvidia/llama-3.3-nemotron-super-49b-v1.5"
    BAIDU_ERNIE_4_5_21B_A3B_THINKING = "baidu/ernie-4.5-21b-a3b-thinking"
    GOOGLE_GEMINI_2_5_FLASH_IMAGE = "google/gemini-2.5-flash-image"
    QWEN_QWEN3_VL_30B_A3B_THINKING = "qwen/qwen3-vl-30b-a3b-thinking"
    QWEN_QWEN3_VL_30B_A3B_INSTRUCT = "qwen/qwen3-vl-30b-a3b-instruct"
    OPENAI_GPT_5_PRO = "openai/gpt-5-pro"
    Z_AI_GLM_4_6 = "z-ai/glm-4.6"
    Z_AI_GLM_4_6_EXACTO = "z-ai/glm-4.6:exacto"
    ANTHROPIC_CLAUDE_SONNET_4_5 = "anthropic/claude-sonnet-4.5"
    DEEPSEEK_DEEPSEEK_V3_2_EXP = "deepseek/deepseek-v3.2-exp"
    THEDRUMMER_CYDONIA_24B_V4_1 = "thedrummer/cydonia-24b-v4.1"
    RELACE_RELACE_APPLY_3 = "relace/relace-apply-3"
    GOOGLE_GEMINI_2_5_FLASH_PREVIEW_09_2025 = "google/gemini-2.5-flash-preview-09-2025"
    GOOGLE_GEMINI_2_5_FLASH_LITE_PREVIEW_09_2025 = "google/gemini-2.5-flash-lite-preview-09-2025"
    QWEN_QWEN3_VL_235B_A22B_THINKING = "qwen/qwen3-vl-235b-a22b-thinking"
    QWEN_QWEN3_VL_235B_A22B_INSTRUCT = "qwen/qwen3-vl-235b-a22b-instruct"
    QWEN_QWEN3_MAX = "qwen/qwen3-max"
    QWEN_QWEN3_CODER_PLUS = "qwen/qwen3-coder-plus"
    OPENAI_GPT_5_CODEX = "openai/gpt-5-codex"
    DEEPSEEK_DEEPSEEK_V3_1_TERMINUS_EXACTO = "deepseek/deepseek-v3.1-terminus:exacto"
    DEEPSEEK_DEEPSEEK_V3_1_TERMINUS = "deepseek/deepseek-v3.1-terminus"
    X_AI_GROK_4_FAST = "x-ai/grok-4-fast"
    ALIBABA_TONGYI_DEEPRESEARCH_30B_A3B_FREE = "alibaba/tongyi-deepresearch-30b-a3b:free"
    ALIBABA_TONGYI_DEEPRESEARCH_30B_A3B = "alibaba/tongyi-deepresearch-30b-a3b"
    QWEN_QWEN3_CODER_FLASH = "qwen/qwen3-coder-flash"
    OPENGVLAB_INTERNVL3_78B = "opengvlab/internvl3-78b"
    QWEN_QWEN3_NEXT_80B_A3B_THINKING = "qwen/qwen3-next-80b-a3b-thinking"
    QWEN_QWEN3_NEXT_80B_A3B_INSTRUCT = "qwen/qwen3-next-80b-a3b-instruct"
    MEITUAN_LONGCAT_FLASH_CHAT_FREE = "meituan/longcat-flash-chat:free"
    MEITUAN_LONGCAT_FLASH_CHAT = "meituan/longcat-flash-chat"
    QWEN_QWEN_PLUS_2025_07_28 = "qwen/qwen-plus-2025-07-28"
    QWEN_QWEN_PLUS_2025_07_28_THINKING = "qwen/qwen-plus-2025-07-28:thinking"
    NVIDIA_NEMOTRON_NANO_9B_V2_FREE = "nvidia/nemotron-nano-9b-v2:free"
    NVIDIA_NEMOTRON_NANO_9B_V2 = "nvidia/nemotron-nano-9b-v2"
    MOONSHOTAI_KIMI_K2_0905 = "moonshotai/kimi-k2-0905"
    MOONSHOTAI_KIMI_K2_0905_EXACTO = "moonshotai/kimi-k2-0905:exacto"
    MOONSHOTAI_KIMI_K2_0905_1T_256K = "moonshotai/kimi-k2-instruct-0905-it-256k"
    DEEPCOGITO_COGITO_V2_PREVIEW_LLAMA_70B = "deepcogito/cogito-v2-preview-llama-70b"
    DEEPCOGITO_COGITO_V2_PREVIEW_LLAMA_109B_MOE = "deepcogito/cogito-v2-preview-llama-109b-moe"
    DEEPCOGITO_COGITO_V2_PREVIEW_DEEPSEEK_671B = "deepcogito/cogito-v2-preview-deepseek-671b"
    STEPFUN_AI_STEP3 = "stepfun-ai/step3"
    QWEN_QWEN3_30B_A3B_THINKING_2507 = "qwen/qwen3-30b-a3b-thinking-2507"
    X_AI_GROK_CODE_FAST_1 = "x-ai/grok-code-fast-1"
    NOUSRESEARCH_HERMES_4_70B = "nousresearch/hermes-4-70b"
    NOUSRESEARCH_HERMES_4_405B = "nousresearch/hermes-4-405b"
    GOOGLE_GEMINI_2_5_FLASH_IMAGE_PREVIEW = "google/gemini-2.5-flash-image-preview"
    DEEPSEEK_DEEPSEEK_CHAT_V3_1 = "deepseek/deepseek-chat-v3.1"
    OPENAI_GPT_4O_AUDIO_PREVIEW = "openai/gpt-4o-audio-preview"
    MISTRALAI_MISTRAL_MEDIUM_3_1 = "mistralai/mistral-medium-3.1"
    BAIDU_ERNIE_4_5_21B_A3B = "baidu/ernie-4.5-21b-a3b"
    BAIDU_ERNIE_4_5_VL_28B_A3B = "baidu/ernie-4.5-vl-28b-a3b"
    Z_AI_GLM_4_5V = "z-ai/glm-4.5v"
    AI21_JAMBA_MINI_1_7 = "ai21/jamba-mini-1.7"
    AI21_JAMBA_LARGE_1_7 = "ai21/jamba-large-1.7"
    OPENAI_GPT_5_CHAT = "openai/gpt-5-chat"
    OPENAI_GPT_5 = "openai/gpt-5"
    OPENAI_GPT_5_MINI = "openai/gpt-5-mini"
    OPENAI_GPT_5_NANO = "openai/gpt-5-nano"
    OPENAI_GPT_OSS_120B = "openai/gpt-oss-120b"
    OPENAI_GPT_OSS_120B_EXACTO = "openai/gpt-oss-120b:exacto"
    OPENAI_GPT_OSS_20B_FREE = "openai/gpt-oss-20b:free"
    OPENAI_GPT_OSS_20B = "openai/gpt-oss-20b"
    ANTHROPIC_CLAUDE_OPUS_4_1 = "anthropic/claude-opus-4.1"
    MISTRALAI_CODESTRAL_2508 = "mistralai/codestral-2508"
    QWEN_QWEN3_CODER_30B_A3B_INSTRUCT = "qwen/qwen3-coder-30b-a3b-instruct"
    QWEN_QWEN3_30B_A3B_INSTRUCT_2507 = "qwen/qwen3-30b-a3b-instruct-2507"
    Z_AI_GLM_4_5 = "z-ai/glm-4.5"
    Z_AI_GLM_4_5_AIR_FREE = "z-ai/glm-4.5-air:free"
    Z_AI_GLM_4_5_AIR = "z-ai/glm-4.5-air"
    QWEN_QWEN3_235B_A22B_THINKING_2507 = "qwen/qwen3-235b-a22b-thinking-2507"
    Z_AI_GLM_4_32B = "z-ai/glm-4-32b"
    QWEN_QWEN3_CODER_FREE = "qwen/qwen3-coder:free"
    QWEN_QWEN3_CODER = "qwen/qwen3-coder"
    QWEN_QWEN3_CODER_EXACTO = "qwen/qwen3-coder:exacto"
    BYTEDANCE_UI_TARS_1_5_7B = "bytedance/ui-tars-1.5-7b"
    GOOGLE_GEMINI_2_5_FLASH_LITE = "google/gemini-2.5-flash-lite"
    QWEN_QWEN3_235B_A22B_2507 = "qwen/qwen3-235b-a22b-2507"
    SWITCHPOINT_ROUTER = "switchpoint/router"
    MOONSHOTAI_KIMI_K2_FREE = "moonshotai/kimi-k2:free"
    MOONSHOTAI_KIMI_K2 = "moonshotai/kimi-k2"
    THUDM_GLM_4_1V_9B_THINKING = "thudm/glm-4.1v-9b-thinking"
    MISTRALAI_DEVSTRAL_MEDIUM = "mistralai/devstral-medium"
    MISTRALAI_DEVSTRAL_SMALL = "mistralai/devstral-small"
    COGNITIVECOMPUTATIONS_DOLPHIN_MISTRAL_24B_VENICE_EDITION_FREE = "cognitivecomputations/dolphin-mistral-24b-venice-edition:free"
    X_AI_GROK_4 = "x-ai/grok-4"
    GOOGLE_GEMMA_3N_E2B_IT_FREE = "google/gemma-3n-e2b-it:free"
    TENCENT_HUNYUAN_A13B_INSTRUCT = "tencent/hunyuan-a13b-instruct"
    TNGTECH_DEEPSEEK_R1T2_CHIMERA_FREE = "tngtech/deepseek-r1t2-chimera:free"
    TNGTECH_DEEPSEEK_R1T2_CHIMERA = "tngtech/deepseek-r1t2-chimera"
    MORPH_MORPH_V3_LARGE = "morph/morph-v3-large"
    MORPH_MORPH_V3_FAST = "morph/morph-v3-fast"
    BAIDU_ERNIE_4_5_VL_424B_A47B = "baidu/ernie-4.5-vl-424b-a47b"
    BAIDU_ERNIE_4_5_300B_A47B = "baidu/ernie-4.5-300b-a47b"
    THEDRUMMER_ANUBIS_70B_V1_1 = "thedrummer/anubis-70b-v1.1"
    INCEPTION_MERCURY = "inception/mercury"
    MISTRALAI_MISTRAL_SMALL_3_2_24B_INSTRUCT = "mistralai/mistral-small-3.2-24b-instruct"
    MINIMAX_MINIMAX_M1 = "minimax/minimax-m1"
    GOOGLE_GEMINI_2_5_FLASH = "google/gemini-2.5-flash"
    GOOGLE_GEMINI_2_5_PRO = "google/gemini-2.5-pro"
    MOONSHOTAI_KIMI_DEV_72B = "moonshotai/kimi-dev-72b"
    OPENAI_O3_PRO = "openai/o3-pro"
    X_AI_GROK_3_MINI = "x-ai/grok-3-mini"
    X_AI_GROK_3 = "x-ai/grok-3"
    MISTRALAI_MAGISTRAL_MEDIUM_2506_THINKING = "mistralai/magistral-medium-2506:thinking"
    GOOGLE_GEMINI_2_5_PRO_PREVIEW = "google/gemini-2.5-pro-preview"
    DEEPSEEK_DEEPSEEK_R1_0528_QWEN3_8B = "deepseek/deepseek-r1-0528-qwen3-8b"
    DEEPSEEK_DEEPSEEK_R1_0528 = "deepseek/deepseek-r1-0528"
    ANTHROPIC_CLAUDE_OPUS_4 = "anthropic/claude-opus-4"
    ANTHROPIC_CLAUDE_SONNET_4 = "anthropic/claude-sonnet-4"
    MISTRALAI_DEVSTRAL_SMALL_2505 = "mistralai/devstral-small-2505"
    GOOGLE_GEMMA_3N_E4B_IT_FREE = "google/gemma-3n-e4b-it:free"
    GOOGLE_GEMMA_3N_E4B_IT = "google/gemma-3n-e4b-it"
    OPENAI_CODEX_MINI = "openai/codex-mini"
    NOUSRESEARCH_DEEPHERMES_3_MISTRAL_24B_PREVIEW = "nousresearch/deephermes-3-mistral-24b-preview"
    MISTRALAI_MISTRAL_MEDIUM_3 = "mistralai/mistral-medium-3"
    GOOGLE_GEMINI_2_5_PRO_PREVIEW_05_06 = "google/gemini-2.5-pro-preview-05-06"
    ARCEE_AI_SPOTLIGHT = "arcee-ai/spotlight"
    ARCEE_AI_MAESTRO_REASONING = "arcee-ai/maestro-reasoning"
    ARCEE_AI_VIRTUOSO_LARGE = "arcee-ai/virtuoso-large"
    ARCEE_AI_CODER_LARGE = "arcee-ai/coder-large"
    MICROSOFT_PHI_4_REASONING_PLUS = "microsoft/phi-4-reasoning-plus"
    INCEPTION_MERCURY_CODER = "inception/mercury-coder"
    QWEN_QWEN3_4B_FREE = "qwen/qwen3-4b:free"
    DEEPSEEK_DEEPSEEK_PROVER_V2 = "deepseek/deepseek-prover-v2"
    META_LLAMA_LLAMA_GUARD_4_12B = "meta-llama/llama-guard-4-12b"
    QWEN_QWEN3_30B_A3B = "qwen/qwen3-30b-a3b"
    QWEN_QWEN3_8B = "qwen/qwen3-8b"
    QWEN_QWEN3_14B = "qwen/qwen3-14b"
    QWEN_QWEN3_32B = "qwen/qwen3-32b"
    QWEN_QWEN3_235B_A22B_FREE = "qwen/qwen3-235b-a22b:free"
    QWEN_QWEN3_235B_A22B = "qwen/qwen3-235b-a22b"
    TNGTECH_DEEPSEEK_R1T_CHIMERA_FREE = "tngtech/deepseek-r1t-chimera:free"
    TNGTECH_DEEPSEEK_R1T_CHIMERA = "tngtech/deepseek-r1t-chimera"
    MICROSOFT_MAI_DS_R1 = "microsoft/mai-ds-r1"
    OPENAI_O4_MINI_HIGH = "openai/o4-mini-high"
    OPENAI_O3 = "openai/o3"
    OPENAI_O4_MINI = "openai/o4-mini"
    QWEN_QWEN2_5_CODER_7B_INSTRUCT = "qwen/qwen2.5-coder-7b-instruct"
    OPENAI_GPT_4_1 = "openai/gpt-4.1"
    OPENAI_GPT_4_1_MINI = "openai/gpt-4.1-mini"
    OPENAI_GPT_4_1_NANO = "openai/gpt-4.1-nano"
    ELEUTHERAI_LLEMMA_7B = "eleutherai/llemma_7b"
    ALFREDPROS_CODELLAMA_7B_INSTRUCT_SOLIDITY = "alfredpros/codellama-7b-instruct-solidity"
    ARLIAI_QWQ_32B_ARLIAI_RPR_V1 = "arliai/qwq-32b-arliai-rpr-v1"
    X_AI_GROK_3_MINI_BETA = "x-ai/grok-3-mini-beta"
    X_AI_GROK_3_BETA = "x-ai/grok-3-beta"
    NVIDIA_LLAMA_3_1_NEMOTRON_ULTRA_253B_V1 = "nvidia/llama-3.1-nemotron-ultra-253b-v1"
    META_LLAMA_LLAMA_4_MAVERICK = "meta-llama/llama-4-maverick"
    META_LLAMA_LLAMA_4_SCOUT = "meta-llama/llama-4-scout"
    QWEN_QWEN2_5_VL_32B_INSTRUCT = "qwen/qwen2.5-vl-32b-instruct"
    DEEPSEEK_DEEPSEEK_CHAT_V3_0324 = "deepseek/deepseek-chat-v3-0324"
    OPENAI_O1_PRO = "openai/o1-pro"
    MISTRALAI_MISTRAL_SMALL_3_1_24B_INSTRUCT_FREE = "mistralai/mistral-small-3.1-24b-instruct:free"
    MISTRALAI_MISTRAL_SMALL_3_1_24B_INSTRUCT = "mistralai/mistral-small-3.1-24b-instruct"
    ALLENAI_OLMO_2_0325_32B_INSTRUCT = "allenai/olmo-2-0325-32b-instruct"
    GOOGLE_GEMMA_3_4B_IT_FREE = "google/gemma-3-4b-it:free"
    GOOGLE_GEMMA_3_4B_IT = "google/gemma-3-4b-it"
    GOOGLE_GEMMA_3_12B_IT_FREE = "google/gemma-3-12b-it:free"
    GOOGLE_GEMMA_3_12B_IT = "google/gemma-3-12b-it"
    COHERE_COMMAND_A = "cohere/command-a"
    OPENAI_GPT_4O_MINI_SEARCH_PREVIEW = "openai/gpt-4o-mini-search-preview"
    OPENAI_GPT_4O_SEARCH_PREVIEW = "openai/gpt-4o-search-preview"
    GOOGLE_GEMMA_3_27B_IT_FREE = "google/gemma-3-27b-it:free"
    GOOGLE_GEMMA_3_27B_IT = "google/gemma-3-27b-it"
    THEDRUMMER_SKYFALL_36B_V2 = "thedrummer/skyfall-36b-v2"
    MICROSOFT_PHI_4_MULTIMODAL_INSTRUCT = "microsoft/phi-4-multimodal-instruct"
    PERPLEXITY_SONAR_REASONING_PRO = "perplexity/sonar-reasoning-pro"
    PERPLEXITY_SONAR_PRO = "perplexity/sonar-pro"
    PERPLEXITY_SONAR_DEEP_RESEARCH = "perplexity/sonar-deep-research"
    QWEN_QWQ_32B = "qwen/qwq-32b"
    GOOGLE_GEMINI_2_0_FLASH_LITE_001 = "google/gemini-2.0-flash-lite-001"
    ANTHROPIC_CLAUDE_3_7_SONNET_THINKING = "anthropic/claude-3.7-sonnet:thinking"
    ANTHROPIC_CLAUDE_3_7_SONNET = "anthropic/claude-3.7-sonnet"
    MISTRALAI_MISTRAL_SABA = "mistralai/mistral-saba"
    META_LLAMA_LLAMA_GUARD_3_8B = "meta-llama/llama-guard-3-8b"
    OPENAI_O3_MINI_HIGH = "openai/o3-mini-high"
    GOOGLE_GEMINI_2_0_FLASH_001 = "google/gemini-2.0-flash-001"
    QWEN_QWEN_VL_PLUS = "qwen/qwen-vl-plus"
    AION_LABS_AION_1_0 = "aion-labs/aion-1.0"
    AION_LABS_AION_1_0_MINI = "aion-labs/aion-1.0-mini"
    AION_LABS_AION_RP_LLAMA_3_1_8B = "aion-labs/aion-rp-llama-3.1-8b"
    QWEN_QWEN_VL_MAX = "qwen/qwen-vl-max"
    QWEN_QWEN_TURBO = "qwen/qwen-turbo"
    QWEN_QWEN2_5_VL_72B_INSTRUCT = "qwen/qwen2.5-vl-72b-instruct"
    QWEN_QWEN_PLUS = "qwen/qwen-plus"
    QWEN_QWEN_MAX = "qwen/qwen-max"
    OPENAI_O3_MINI = "openai/o3-mini"
    MISTRALAI_MISTRAL_SMALL_24B_INSTRUCT_2501 = "mistralai/mistral-small-24b-instruct-2501"
    DEEPSEEK_DEEPSEEK_R1_DISTILL_QWEN_32B = "deepseek/deepseek-r1-distill-qwen-32b"
    DEEPSEEK_DEEPSEEK_R1_DISTILL_QWEN_14B = "deepseek/deepseek-r1-distill-qwen-14b"
    PERPLEXITY_SONAR_REASONING = "perplexity/sonar-reasoning"
    PERPLEXITY_SONAR = "perplexity/sonar"
    DEEPSEEK_DEEPSEEK_R1_DISTILL_LLAMA_70B = "deepseek/deepseek-r1-distill-llama-70b"
    DEEPSEEK_DEEPSEEK_R1 = "deepseek/deepseek-r1"
    MINIMAX_MINIMAX_01 = "minimax/minimax-01"
    MICROSOFT_PHI_4 = "microsoft/phi-4"
    SAO10K_L3_1_70B_HANAMI_X1 = "sao10k/l3.1-70b-hanami-x1"
    DEEPSEEK_DEEPSEEK_CHAT = "deepseek/deepseek-chat"
    SAO10K_L3_3_EURYALE_70B = "sao10k/l3.3-euryale-70b"
    OPENAI_O1 = "openai/o1"
    COHERE_COMMAND_R7B_12_2024 = "cohere/command-r7b-12-2024"
    GOOGLE_GEMINI_2_0_FLASH_EXP_FREE = "google/gemini-2.0-flash-exp:free"
    META_LLAMA_LLAMA_3_3_70B_INSTRUCT_FREE = "meta-llama/llama-3.3-70b-instruct:free"
    META_LLAMA_LLAMA_3_3_70B_INSTRUCT = "meta-llama/llama-3.3-70b-instruct"
    AMAZON_NOVA_LITE_V1 = "amazon/nova-lite-v1"
    AMAZON_NOVA_MICRO_V1 = "amazon/nova-micro-v1"
    AMAZON_NOVA_PRO_V1 = "amazon/nova-pro-v1"
    OPENAI_GPT_4O_2024_11_20 = "openai/gpt-4o-2024-11-20"
    MISTRALAI_MISTRAL_LARGE_2411 = "mistralai/mistral-large-2411"
    MISTRALAI_MISTRAL_LARGE_2407 = "mistralai/mistral-large-2407"
    MISTRALAI_PIXTRAL_LARGE_2411 = "mistralai/pixtral-large-2411"
    QWEN_QWEN_2_5_CODER_32B_INSTRUCT = "qwen/qwen-2.5-coder-32b-instruct"
    RAIFLE_SORCERERLM_8X22B = "raifle/sorcererlm-8x22b"
    THEDRUMMER_UNSLOPNEMO_12B = "thedrummer/unslopnemo-12b"
    ANTHROPIC_CLAUDE_3_5_HAIKU_20241022 = "anthropic/claude-3.5-haiku-20241022"
    ANTHROPIC_CLAUDE_3_5_HAIKU = "anthropic/claude-3.5-haiku"
    ANTHRACITE_ORG_MAGNUM_V4_72B = "anthracite-org/magnum-v4-72b"
    ANTHROPIC_CLAUDE_3_5_SONNET = "anthropic/claude-3.5-sonnet"
    MISTRALAI_MINISTRAL_8B = "mistralai/ministral-8b"
    MISTRALAI_MINISTRAL_3B = "mistralai/ministral-3b"
    QWEN_QWEN_2_5_7B_INSTRUCT = "qwen/qwen-2.5-7b-instruct"
    NVIDIA_LLAMA_3_1_NEMOTRON_70B_INSTRUCT = "nvidia/llama-3.1-nemotron-70b-instruct"
    INFLECTION_INFLECTION_3_PI = "inflection/inflection-3-pi"
    INFLECTION_INFLECTION_3_PRODUCTIVITY = "inflection/inflection-3-productivity"
    THEDRUMMER_ROCINANTE_12B = "thedrummer/rocinante-12b"
    META_LLAMA_LLAMA_3_2_3B_INSTRUCT_FREE = "meta-llama/llama-3.2-3b-instruct:free"
    META_LLAMA_LLAMA_3_2_3B_INSTRUCT = "meta-llama/llama-3.2-3b-instruct"
    META_LLAMA_LLAMA_3_2_1B_INSTRUCT = "meta-llama/llama-3.2-1b-instruct"
    META_LLAMA_LLAMA_3_2_90B_VISION_INSTRUCT = "meta-llama/llama-3.2-90b-vision-instruct"
    META_LLAMA_LLAMA_3_2_11B_VISION_INSTRUCT = "meta-llama/llama-3.2-11b-vision-instruct"
    QWEN_QWEN_2_5_72B_INSTRUCT = "qwen/qwen-2.5-72b-instruct"
    NEVERSLEEP_LLAMA_3_1_LUMIMAID_8B = "neversleep/llama-3.1-lumimaid-8b"
    MISTRALAI_PIXTRAL_12B = "mistralai/pixtral-12b"
    COHERE_COMMAND_R_08_2024 = "cohere/command-r-08-2024"
    COHERE_COMMAND_R_PLUS_08_2024 = "cohere/command-r-plus-08-2024"
    SAO10K_L3_1_EURYALE_70B = "sao10k/l3.1-euryale-70b"
    QWEN_QWEN_2_5_VL_7B_INSTRUCT = "qwen/qwen-2.5-vl-7b-instruct"
    MICROSOFT_PHI_3_5_MINI_128K_INSTRUCT = "microsoft/phi-3.5-mini-128k-instruct"
    NOUSRESEARCH_HERMES_3_LLAMA_3_1_70B = "nousresearch/hermes-3-llama-3.1-70b"
    NOUSRESEARCH_HERMES_3_LLAMA_3_1_405B_FREE = "nousresearch/hermes-3-llama-3.1-405b:free"
    NOUSRESEARCH_HERMES_3_LLAMA_3_1_405B = "nousresearch/hermes-3-llama-3.1-405b"
    OPENAI_CHATGPT_4O_LATEST = "openai/chatgpt-4o-latest"
    SAO10K_L3_LUNARIS_8B = "sao10k/l3-lunaris-8b"
    OPENAI_GPT_4O_2024_08_06 = "openai/gpt-4o-2024-08-06"
    META_LLAMA_LLAMA_3_1_405B = "meta-llama/llama-3.1-405b"
    META_LLAMA_LLAMA_3_1_8B_INSTRUCT = "meta-llama/llama-3.1-8b-instruct"
    META_LLAMA_LLAMA_3_1_405B_INSTRUCT = "meta-llama/llama-3.1-405b-instruct"
    META_LLAMA_LLAMA_3_1_70B_INSTRUCT = "meta-llama/llama-3.1-70b-instruct"
    MISTRALAI_MISTRAL_NEMO = "mistralai/mistral-nemo"
    OPENAI_GPT_4O_MINI_2024_07_18 = "openai/gpt-4o-mini-2024-07-18"
    OPENAI_GPT_4O_MINI = "openai/gpt-4o-mini"
    GOOGLE_GEMMA_2_27B_IT = "google/gemma-2-27b-it"
    GOOGLE_GEMMA_2_9B_IT = "google/gemma-2-9b-it"
    SAO10K_L3_EURYALE_70B = "sao10k/l3-euryale-70b"
    NOUSRESEARCH_HERMES_2_PRO_LLAMA_3_8B = "nousresearch/hermes-2-pro-llama-3-8b"
    MISTRALAI_MISTRAL_7B_INSTRUCT_FREE = "mistralai/mistral-7b-instruct:free"
    MISTRALAI_MISTRAL_7B_INSTRUCT = "mistralai/mistral-7b-instruct"
    MISTRALAI_MISTRAL_7B_INSTRUCT_V0_3 = "mistralai/mistral-7b-instruct-v0.3"
    MICROSOFT_PHI_3_MINI_128K_INSTRUCT = "microsoft/phi-3-mini-128k-instruct"
    MICROSOFT_PHI_3_MEDIUM_128K_INSTRUCT = "microsoft/phi-3-medium-128k-instruct"
    META_LLAMA_LLAMA_GUARD_2_8B = "meta-llama/llama-guard-2-8b"
    OPENAI_GPT_4O_2024_05_13 = "openai/gpt-4o-2024-05-13"
    OPENAI_GPT_4O = "openai/gpt-4o"
    OPENAI_GPT_4O_EXTENDED = "openai/gpt-4o:extended"
    META_LLAMA_LLAMA_3_70B_INSTRUCT = "meta-llama/llama-3-70b-instruct"
    META_LLAMA_LLAMA_3_8B_INSTRUCT = "meta-llama/llama-3-8b-instruct"
    MISTRALAI_MIXTRAL_8X22B_INSTRUCT = "mistralai/mixtral-8x22b-instruct"
    MICROSOFT_WIZARDLM_2_8X22B = "microsoft/wizardlm-2-8x22b"
    OPENAI_GPT_4_TURBO = "openai/gpt-4-turbo"
    ANTHROPIC_CLAUDE_3_HAIKU = "anthropic/claude-3-haiku"
    ANTHROPIC_CLAUDE_3_OPUS = "anthropic/claude-3-opus"
    MISTRALAI_MISTRAL_LARGE = "mistralai/mistral-large"
    OPENAI_GPT_3_5_TURBO_0613 = "openai/gpt-3.5-turbo-0613"
    OPENAI_GPT_4_TURBO_PREVIEW = "openai/gpt-4-turbo-preview"
    MISTRALAI_MISTRAL_TINY = "mistralai/mistral-tiny"
    MISTRALAI_MISTRAL_7B_INSTRUCT_V0_2 = "mistralai/mistral-7b-instruct-v0.2"
    MISTRALAI_MIXTRAL_8X7B_INSTRUCT = "mistralai/mixtral-8x7b-instruct"
    NEVERSLEEP_NOROMAID_20B = "neversleep/noromaid-20b"
    ALPINDALE_GOLIATH_120B = "alpindale/goliath-120b"
    OPENROUTER_AUTO = "openrouter/auto"
    OPENAI_GPT_4_1106_PREVIEW = "openai/gpt-4-1106-preview"
    OPENAI_GPT_3_5_TURBO_INSTRUCT = "openai/gpt-3.5-turbo-instruct"
    MISTRALAI_MISTRAL_7B_INSTRUCT_V0_1 = "mistralai/mistral-7b-instruct-v0.1"
    OPENAI_GPT_3_5_TURBO_16K = "openai/gpt-3.5-turbo-16k"
    MANCER_WEAVER = "mancer/weaver"
    UNDI95_REMM_SLERP_L2_13B = "undi95/remm-slerp-l2-13b"
    GRYPHE_MYTHOMAX_L2_13B = "gryphe/mythomax-l2-13b"
    OPENAI_GPT_4_0314 = "openai/gpt-4-0314"
    OPENAI_GPT_4 = "openai/gpt-4"
    OPENAI_GPT_3_5_TURBO = "openai/gpt-3.5-turbo"


# OracleModels
class OracleModels:
    """OracleModels constants."""
    OPENAI_GPT_OSS_120B = "openai.gpt-oss-120b"
    OPENAI_GPT_OSS_20B = "openai.gpt-oss-20b"
    XAI_GROK_CODE_FAST_1 = "xai.grok-code-fast-1"
    XAI_GROK_4 = "xai.grok-4"
    XAI_GROK_3 = "xai.grok-3"
    XAI_GROK_4_FAST_REASONING = "xai.grok-4-fast-reasoning"
    XAI_GROK_4_FAST_NON_REASONING = "xai.grok-4-fast-non-reasoning"
    XAI_GROK_3_MINI = "xai.grok-3-mini"
    XAI_GROK_3_FAST = "xai.grok-3-fast"
    XAI_GROK_3_MINI_FAST = "xai.grok-3-mini-fast"
    GOOGLE_GEMINI_2_5_PRO = "google.gemini-2.5-pro"
    GOOGLE_GEMINI_2_5_FLASH_LITE = "google.gemini-2.5-flash-lite"
    GOOGLE_GEMINI_2_5_FLASH = "google.gemini-2.5-flash"


# PaLMModels
class PaLMModels:
    """PaLMModels constants."""
    MODELS_TEXT_BISON_001 = "models/text-bison-001"
    MODELS_CHAT_BISON_001 = "models/chat-bison-001"


# PerplexityAIModels
class PerplexityAIModels:
    """PerplexityAIModels constants."""
    CODELLAMA_34B_INSTRUCT = "codellama-34b-instruct"
    CODELLAMA_70B_INSTRUCT = "codellama-70b-instruct"
    LLAMA_2_70B_CHAT = "llama-2-70b-chat"
    MISTRAL_7B_INSTRUCT = "mistral-7b-instruct"
    MIXTRAL_8X7B_INSTRUCT = "mixtral-8x7b-instruct"
    PPLX_7B_CHAT = "pplx-7b-chat"
    PPLX_70B_CHAT = "pplx-70b-chat"
    PPLX_7B_ONLINE = "pplx-7b-online"
    PPLX_70B_ONLINE = "pplx-70b-online"
    LLAMA_3_8B_INSTRUCT = "llama-3-8b-instruct"
    LLAMA_3_70B_INSTRUCT = "llama-3-70b-instruct"
    LLAMA_3_SONAR_SMALL_32K_CHAT = "llama-3-sonar-small-32k-chat"
    LLAMA_3_SONAR_LARGE_32K_CHAT = "llama-3-sonar-large-32k-chat"
    LLAMA_3_SONAR_SMALL_32K_ONLINE = "llama-3-sonar-small-32k-online"
    LLAMA_3_SONAR_LARGE_32K_ONLINE = "llama-3-sonar-large-32k-online"
    LLAMA_3_1_SONAR_SMALL_128K_ONLINE = "llama-3.1-sonar-small-128k-online"
    LLAMA_3_1_SONAR_LARGE_128K_ONLINE = "llama-3.1-sonar-large-128k-online"
    LLAMA_3_1_SONAR_HUGE_128K_ONLINE = "llama-3.1-sonar-huge-128k-online"
    LLAMA_3_1_SONAR_SMALL_128K_CHAT = "llama-3.1-sonar-small-128k-chat"
    LLAMA_3_1_SONAR_LARGE_128K_CHAT = "llama-3.1-sonar-large-128k-chat"
    LLAMA_3_1_8B_INSTRUCT = "llama-3.1-8b-instruct"
    LLAMA_3_1_70B_INSTRUCT = "llama-3.1-70b-instruct"
    SONAR_REASONING = "sonar-reasoning"
    SONAR_PRO = "sonar-pro"
    SONAR = "sonar"
    SONAR_REASONING_PRO = "sonar-reasoning-pro"
    SONAR_DEEP_RESEARCH = "sonar-deep-research"
    R1_1776 = "r1-1776"


# PredibaseModels
class PredibaseModels:
    """PredibaseModels constants."""
    MIXTRAL_8X7B_V0_1 = "mixtral-8x7b-v0-1"
    MIXTRAL_8X7B_INSTRUCT_V0_1 = "mixtral-8x7b-instruct-v0-1"
    MODEL_7B = "7b"
    MODEL_21B = "21b"
    MODEL_70B = "70b"


# RekaAIModels
class RekaAIModels:
    """RekaAIModels constants."""
    REKA_EDGE = "reka-edge"
    REKA_FLASH = "reka-flash"
    REKA_CORE = "reka-core"
    REKA_CORE_20240501 = "reka-core-20240501"
    REKA_CORE_20240415 = "reka-core-20240415"
    REKA_FLASH_20240226 = "reka-flash-20240226"
    REKA_EDGE_20240208 = "reka-edge-20240208"


# SonioxModels
class SonioxModels:
    """SonioxModels constants."""
    REAL_TIME = "real-time"


# StabilityAIModels
class StabilityAIModels:
    """StabilityAIModels constants."""
    ULTRA = "ultra"
    CORE = "core"
    SD3_LARGE = "sd3-large"
    SD3_MEDIUM = "sd3-medium"
    SD3_LARGE_TURBO = "sd3-large-turbo"
    SD3_5_MEDIUM = "sd3.5-medium"
    STABLE_DIFFUSION_XL_1024_V1_0 = "stable-diffusion-xl-1024-v1-0"
    STABLE_DIFFUSION_V1_6 = "stable-diffusion-v1-6"
    STABLE_DIFFUSION_XL_BETA_V2_2_2 = "stable-diffusion-xl-beta-v2-2-2"
    SD3_5_LARGE = "sd3.5-large"
    SD3_5_LARGE_TURBO = "sd3.5-large-turbo"


# TogetherAIModels
class TogetherAIModels:
    """TogetherAIModels constants."""
    MISTRALAI_MISTRAL_7B_INSTRUCT_V0_2 = "mistralai/Mistral-7B-Instruct-v0.2"
    MISTRALAI_MIXTRAL_8X7B_INSTRUCT_V0_1 = "mistralai/Mixtral-8x7B-Instruct-v0.1"
    MISTRALAI_MIXTRAL_8X7B_V0_1 = "mistralai/Mixtral-8x7B-v0.1"
    OPENCHAT_OPENCHAT_3_5_1210 = "openchat/openchat-3.5-1210"
    TOGETHERCOMPUTER_STRIPEDHYENA_NOUS_7B = "togethercomputer/StripedHyena-Nous-7B"
    TOGETHERCOMPUTER_STRIPEDHYENA_HESSIAN_7B = "togethercomputer/StripedHyena-Hessian-7B"
    DISCORESEARCH_DISCOLM_MIXTRAL_8X7B_V2 = "DiscoResearch/DiscoLM-mixtral-8x7b-v2"
    META_LLAMA_LLAMA_GUARD_7B = "Meta-Llama/Llama-Guard-7b"
    ZERO_ONE_AI_YI_34B_CHAT = "zero-one-ai/Yi-34B-Chat"
    ZERO_ONE_AI_YI_34B = "zero-one-ai/Yi-34B"
    ZERO_ONE_AI_YI_6B = "zero-one-ai/Yi-6B"
    NEXUSFLOW_NEXUSRAVEN_V2_13B = "Nexusflow/NexusRaven-V2-13B"
    NOUSRESEARCH_NOUS_CAPYBARA_7B_V1P9 = "NousResearch/Nous-Capybara-7B-V1p9"
    TEKNIUM_OPENHERMES_2P5_MISTRAL_7B = "teknium/OpenHermes-2p5-Mistral-7B"
    TOGETHERCOMPUTER_LLAMA_2_70B_CHAT = "togethercomputer/llama-2-70b-chat"
    TOGETHERCOMPUTER_LLAMA_2_13B_CHAT = "togethercomputer/llama-2-13b-chat"
    TOGETHERCOMPUTER_LLAMA_2_7B_CHAT = "togethercomputer/llama-2-7b-chat"
    NOUSRESEARCH_NOUS_HERMES_LLAMA2_13B = "NousResearch/Nous-Hermes-Llama2-13b"
    NOUSRESEARCH_NOUS_HERMES_LLAMA_2_7B = "NousResearch/Nous-Hermes-llama-2-7b"
    OPEN_ORCA_MISTRAL_7B_OPENORCA = "Open-Orca/Mistral-7B-OpenOrca"
    TEKNIUM_OPENHERMES_2_MISTRAL_7B = "teknium/OpenHermes-2-Mistral-7B"
    WIZARDLM_WIZARDLM_13B_V1_2 = "WizardLM/WizardLM-13B-V1.2"
    WIZARDLM_WIZARDCODER_PYTHON_34B_V1_0 = "WizardLM/WizardCoder-Python-34B-V1.0"
    TOGETHERCOMPUTER_LLAMA_2_7B_32K = "togethercomputer/LLaMA-2-7B-32K"
    TOGETHERCOMPUTER_CODELLAMA_34B_INSTRUCT = "togethercomputer/CodeLlama-34b-Instruct"
    TOGETHERCOMPUTER_CODELLAMA_34B_PYTHON = "togethercomputer/CodeLlama-34b-Python"
    ELEUTHERAI_LLEMMA_7B = "EleutherAI/llemma_7b"
    LMSYS_VICUNA_13B_V1_5_16K = "lmsys/vicuna-13b-v1.5-16k"
    LMSYS_VICUNA_13B_V1_5 = "lmsys/vicuna-13b-v1.5"
    PHIND_PHIND_CODELLAMA_34B_PYTHON_V1 = "Phind/Phind-CodeLlama-34B-Python-v1"
    PHIND_PHIND_CODELLAMA_34B_V2 = "Phind/Phind-CodeLlama-34B-v2"
    TOGETHERCOMPUTER_CODELLAMA_13B_INSTRUCT = "togethercomputer/CodeLlama-13b-Instruct"
    TOGETHERCOMPUTER_CODELLAMA_7B_INSTRUCT = "togethercomputer/CodeLlama-7b-Instruct"
    TOGETHERCOMPUTER_CODELLAMA_13B_PYTHON = "togethercomputer/CodeLlama-13b-Python"
    TOGETHERCOMPUTER_CODELLAMA_7B_PYTHON = "togethercomputer/CodeLlama-7b-Python"
    TOGETHERCOMPUTER_CODELLAMA_34B = "togethercomputer/CodeLlama-34b"
    TOGETHERCOMPUTER_CODELLAMA_13B = "togethercomputer/CodeLlama-13b"
    TOGETHERCOMPUTER_CODELLAMA_7B = "togethercomputer/CodeLlama-7b"
    TOGETHERCOMPUTER_LLAMA_2_70B = "togethercomputer/llama-2-70b"
    TOGETHERCOMPUTER_LLAMA_2_13B = "togethercomputer/llama-2-13b"
    TOGETHERCOMPUTER_LLAMA_2_7B = "togethercomputer/llama-2-7b"
    AUSTISM_CHRONOS_HERMES_13B = "Austism/chronos-hermes-13b"
    NUMBERSSTATION_NSQL_LLAMA_2_7B = "NumbersStation/nsql-llama-2-7B"
    GARAGE_BAIND_PLATYPUS2_70B_INSTRUCT = "garage-bAInd/Platypus2-70B-instruct"
    WIZARDLM_WIZARDLM_70B_V1_0 = "WizardLM/WizardLM-70B-V1.0"
    GRYPHE_MYTHOMAX_L2_13B = "Gryphe/MythoMax-L2-13b"
    UPSTAGE_SOLAR_0_70B_16BIT = "upstage/SOLAR-0-70b-16bit"
    TOGETHERCOMPUTER_QWEN_7B_CHAT = "togethercomputer/Qwen-7B-Chat"
    TOGETHERCOMPUTER_QWEN_7B = "togethercomputer/Qwen-7B"
    TOGETHERCOMPUTER_REDPAJAMA_INCITE_7B_CHAT = "togethercomputer/RedPajama-INCITE-7B-Chat"
    TOGETHERCOMPUTER_REDPAJAMA_INCITE_7B_INSTRUCT = "togethercomputer/RedPajama-INCITE-7B-Instruct"
    TOGETHERCOMPUTER_REDPAJAMA_INCITE_7B_BASE = "togethercomputer/RedPajama-INCITE-7B-Base"
    TOGETHERCOMPUTER_REDPAJAMA_INCITE_CHAT_3B_V1 = "togethercomputer/RedPajama-INCITE-Chat-3B-v1"
    TOGETHERCOMPUTER_REDPAJAMA_INCITE_INSTRUCT_3B_V1 = "togethercomputer/RedPajama-INCITE-Instruct-3B-v1"
    TOGETHERCOMPUTER_REDPAJAMA_INCITE_BASE_3B_V1 = "togethercomputer/RedPajama-INCITE-Base-3B-v1"
    HUGGYLLAMA_LLAMA_65B = "huggyllama/llama-65b"
    TOGETHERCOMPUTER_GPT_JT_6B_V1 = "togethercomputer/GPT-JT-6B-v1"
    TOGETHERCOMPUTER_GPT_JT_MODERATION_6B = "togethercomputer/GPT-JT-Moderation-6B"
    TOGETHERCOMPUTER_GPT_NEOXT_CHAT_BASE_20B = "togethercomputer/GPT-NeoXT-Chat-Base-20B"
    TOGETHERCOMPUTER_PYTHIA_CHAT_BASE_7B_V0_16 = "togethercomputer/Pythia-Chat-Base-7B-v0.16"
    TOGETHERCOMPUTER_ALPACA_7B = "togethercomputer/alpaca-7b"
    TOGETHERCOMPUTER_FALCON_40B_INSTRUCT = "togethercomputer/falcon-40b-instruct"
    TOGETHERCOMPUTER_FALCON_40B = "togethercomputer/falcon-40b"
    TOGETHERCOMPUTER_FALCON_7B_INSTRUCT = "togethercomputer/falcon-7b-instruct"
    TOGETHERCOMPUTER_FALCON_7B = "togethercomputer/falcon-7b"
    UPSTAGE_SOLAR_10_7B_INSTRUCT_V1_0 = "upstage/SOLAR-10.7B-Instruct-v1.0"
    TOGETHERCOMPUTER_M2_BERT_80M_2K_RETRIEVAL = "togethercomputer/m2-bert-80M-2k-retrieval"
    TOGETHERCOMPUTER_M2_BERT_80M_8K_RETRIEVAL = "togethercomputer/m2-bert-80M-8k-retrieval"
    TOGETHERCOMPUTER_M2_BERT_80M_32K_RETRIEVAL = "togethercomputer/m2-bert-80M-32k-retrieval"
    WHEREISAI_UAE_LARGE_V1 = "WhereIsAI/UAE-Large-V1"
    BAAI_BGE_LARGE_EN_V1_5 = "BAAI/bge-large-en-v1.5"
    BAAI_BGE_BASE_EN_V1_5 = "BAAI/bge-base-en-v1.5"
    SENTENCE_TRANSFORMERS_MSMARCO_BERT_BASE_DOT_V5 = "sentence-transformers/msmarco-bert-base-dot-v5"
    BERT_BASE_UNCASED = "bert-base-uncased"
    DATABRICKS_DBRX_INSTRUCT = "databricks/dbrx-instruct"
    MISTRALAI_MIXTRAL_8X22B = "mistralai/Mixtral-8x22B"
    MISTRALAI_MISTRAL_7B_INSTRUCT_V0_1 = "mistralai/Mistral-7B-Instruct-v0.1"
    META_LLAMA_LLAMA_2_7B_CHAT_HF = "meta-llama/Llama-2-7b-chat-hf"
    META_LLAMA_LLAMA_3_8B_CHAT_HF = "meta-llama/Llama-3-8b-chat-hf"
    META_LLAMA_LLAMA_3_70B_CHAT_HF = "meta-llama/Llama-3-70b-chat-hf"
    META_LLAMA_META_LLAMA_3_1_8B_INSTRUCT_REFERENCE = "meta-llama/Meta-Llama-3.1-8B-Instruct-Reference"
    META_LLAMA_META_LLAMA_3_1_70B_INSTRUCT_TURBO = "meta-llama/Meta-Llama-3.1-70B-Instruct-Turbo"
    META_LLAMA_META_LLAMA_3_1_405B_INSTRUCT_TURBO = "meta-llama/Meta-Llama-3.1-405B-Instruct-Turbo"
    META_LLAMA_META_LLAMA_3_1_8B_INSTRUCT_TURBO = "meta-llama/Meta-Llama-3.1-8B-Instruct-Turbo"
    META_LLAMA_META_LLAMA_3_1_8B_REFERENCE = "meta-llama/Meta-Llama-3.1-8B-Reference"
    META_LLAMA_META_LLAMA_3_1_70B_INSTRUCT_REFERENCE = "meta-llama/Meta-Llama-3.1-70B-Instruct-Reference"
    META_LLAMA_META_LLAMA_3_1_70B_REFERENCE = "meta-llama/Meta-Llama-3.1-70B-Reference"
    META_LLAMA_LLAMA_3_2_3B_INSTRUCT_TURBO = "meta-llama/Llama-3.2-3B-Instruct-Turbo"
    META_LLAMA_LLAMA_3_2_90B_VISION_INSTRUCT_TURBO = "meta-llama/Llama-3.2-90B-Vision-Instruct-Turbo"
    META_LLAMA_LLAMA_3_2_11B_VISION_INSTRUCT_TURBO = "meta-llama/Llama-3.2-11B-Vision-Instruct-Turbo"
    META_LLAMA_LLAMA_3_3_70B_INSTRUCT_TURBO = "meta-llama/Llama-3.3-70B-Instruct-Turbo"
    DEEPSEEK_AI_DEEPSEEK_R1 = "deepseek-ai/DeepSeek-R1"
    DEEPSEEK_AI_DEEPSEEK_V3 = "deepseek-ai/DeepSeek-V3"
    DEEPSEEK_AI_DEEPSEEK_LLM_67B_CHAT = "deepseek-ai/deepseek-llm-67b-chat"
    META_LLAMA_LLAMA_4_MAVERICK_17B_128E_INSTRUCT_FP8 = "meta-llama/Llama-4-Maverick-17B-128E-Instruct-FP8"
    META_LLAMA_LLAMA_4_SCOUT_17B_16E_INSTRUCT = "meta-llama/Llama-4-Scout-17B-16E-Instruct"
    QWEN_QWEN3_235B_A22B_FP8_TPUT = "Qwen/Qwen3-235B-A22B-fp8-tput"
    DEEPSEEK_AI_DEEPSEEK_V3_1 = "deepseek-ai/DeepSeek-V3.1"
    OPENAI_GPT_OSS_120B = "openai/gpt-oss-120b"
    OPENAI_GPT_OSS_20B = "openai/gpt-oss-20b"
    MOONSHOTAI_KIMI_K2_INSTRUCT = "moonshotai/Kimi-K2-Instruct"
    MOONSHOTAI_KIMI_K2_INSTRUCT_0905 = "moonshotai/Kimi-K2-Instruct-0905"
    ZAI_ORG_GLM_4_5_AIR_FP8 = "zai-org/GLM-4.5-Air-FP8"
    QWEN_QWEN3_235B_A22B_THINKING_2507 = "Qwen/Qwen3-235B-A22B-Thinking-2507"
    QWEN_QWEN3_CODER_480B_A35B_INSTRUCT_FP8 = "Qwen/Qwen3-Coder-480B-A35B-Instruct-FP8"
    QWEN_QWEN3_235B_A22B_INSTRUCT_2507_TPUT = "Qwen/Qwen3-235B-A22B-Instruct-2507-tput"
    DEEPSEEK_AI_DEEPSEEK_R1_0528_TPUT = "deepseek-ai/DeepSeek-R1-0528-tput"
    DEEPSEEK_AI_DEEPSEEK_R1_DISTILL_LLAMA_70B = "deepseek-ai/DeepSeek-R1-Distill-Llama-70B"
    DEEPSEEK_AI_DEEPSEEK_R1_DISTILL_QWEN_14B = "deepseek-ai/DeepSeek-R1-Distill-Qwen-14B"
    MARIN_COMMUNITY_MARIN_8B_INSTRUCT = "marin-community/marin-8b-instruct"
    MISTRALAI_MISTRAL_SMALL_24B_INSTRUCT_2501 = "mistralai/Mistral-Small-24B-Instruct-2501"
    QWEN_QWEN2_5_7B_INSTRUCT_TURBO = "Qwen/Qwen2.5-7B-Instruct-Turbo"
    QWEN_QWEN2_5_72B_INSTRUCT_TURBO = "Qwen/Qwen2.5-72B-Instruct-Turbo"
    QWEN_QWEN2_5_VL_72B_INSTRUCT = "Qwen/Qwen2.5-VL-72B-Instruct"
    QWEN_QWEN2_5_CODER_32B_INSTRUCT = "Qwen/Qwen2.5-Coder-32B-Instruct"
    QWEN_QWQ_32B = "Qwen/QwQ-32B"
    ARCEE_AI_CODER_LARGE = "arcee-ai/coder-large"
    ARCEE_AI_VIRTUOSO_LARGE = "arcee-ai/virtuoso-large"
    ARCEE_AI_MAESTRO_REASONING = "arcee-ai/maestro-reasoning"
    DEEPCOGITO_COGITO_V2_PREVIEW_LLAMA_70B = "deepcogito/cogito-v2-preview-llama-70B"
    DEEPCOGITO_COGITO_V2_PREVIEW_LLAMA_109B_MOE = "deepcogito/cogito-v2-preview-llama-109B-MoE"
    DEEPCOGITO_COGITO_V2_PREVIEW_LLAMA_405B = "deepcogito/cogito-v2-preview-llama-405B"
    DEEPCOGITO_COGITO_V2_PREVIEW_DEEPSEEK_671B = "deepcogito/cogito-v2-preview-deepseek-671b"
    META_LLAMA_META_LLAMA_3_8B_INSTRUCT_LITE = "meta-llama/Meta-Llama-3-8B-Instruct-Lite"
    GOOGLE_GEMMA_3N_E4B_IT = "google/gemma-3n-E4B-it"
    BLACK_FOREST_LABS_FLUX_1_PRO = "black-forest-labs/FLUX.1-pro"
    BLACK_FOREST_LABS_FLUX_1_DEV = "black-forest-labs/FLUX.1-dev"
    BLACK_FOREST_LABS_FLUX_1_KONTEXT_PRO = "black-forest-labs/FLUX.1-kontext-pro"
    BLACK_FOREST_LABS_FLUX_1_KONTEXT_MAX = "black-forest-labs/FLUX.1-kontext-max"
    BLACK_FOREST_LABS_FLUX_1_KONTEXT_DEV = "black-forest-labs/FLUX.1-kontext-dev"
    BLACK_FOREST_LABS_FLUX_1_KREA_DEV = "black-forest-labs/FLUX.1-krea-dev"
    BLACK_FOREST_LABS_FLUX_1_SCHNELL = "black-forest-labs/FLUX.1-schnell"
    BLACK_FOREST_LABS_FLUX_1_CANNY_PRO = "black-forest-labs/FLUX.1-Canny-pro"
    GOOGLE_IMAGEN_4_0_PREVIEW = "google/imagen-4.0-preview"
    GOOGLE_IMAGEN_4_0_FAST = "google/imagen-4.0-fast"
    GOOGLE_IMAGEN_4_0_ULTRA = "google/imagen-4.0-ultra"
    BYTEDANCE_SEED_SEEDREAM_3_0 = "ByteDance-Seed/Seedream-3.0"
    BYTEDANCE_SEED_SEEDREAM_4_0 = "ByteDance-Seed/Seedream-4.0"
    BYTEDANCE_SEED_SEEDEDIT = "ByteDance-Seed/SeedEdit"
    QWEN_QWEN_IMAGE_EDIT = "Qwen/Qwen-Image-Edit"
    QWEN_QWEN_IMAGE = "Qwen/Qwen-Image"
    RUNDIFFUSION_JUGGERNAUT_PRO_FLUX = "RunDiffusion/Juggernaut-pro-flux"
    RUNDIFFUSION_JUGGERNAUT_LIGHTNING_FLUX = "Rundiffusion/Juggernaut-Lightning-Flux"
    HIDREAM_AI_HIDREAM_I1_FULL = "HiDream-ai/HiDream-I1-Full"
    HIDREAM_AI_HIDREAM_I1_DEV = "HiDream-ai/HiDream-I1-Dev"
    HIDREAM_AI_HIDREAM_I1_FAST = "HiDream-ai/HiDream-I1-Fast"
    IDEOGRAM_IDEOGRAM_3_0 = "ideogram/ideogram-3.0"
    LYKON_DREAMSHAPER = "Lykon/DreamShaper"
    STABILITYAI_STABLE_DIFFUSION_XL_BASE_1_0 = "stabilityai/stable-diffusion-xl-base-1.0"
    STABILITYAI_STABLE_DIFFUSION_3_MEDIUM = "stabilityai/stable-diffusion-3-medium"
    GOOGLE_FLASH_IMAGE_2_5 = "google/flash-image-2.5"
    BLACK_FOREST_LABS_FLUX_1_1_PRO = "black-forest-labs/FLUX.1.1-pro"
    MOONSHOT_AI_KIMI_K2_INSTRUCT = "moonshot-ai/kimi-k2-instruct"
    MOONSHOT_AI_KIMI_K2_THINKING = "moonshot-ai/kimi-k2-thinking"
    MOONSHOT_AI_KIMI_K2_INSTRUCT_0905 = "moonshot-ai/kimi-k2-instruct-0905"
    MOONSHOTAI_KIMI_K2_THINKING = "moonshotai/Kimi-K2-Thinking"


# VertexAIModels
class VertexAIModels:
    """VertexAIModels constants."""
    GEMINI_1_0_PRO = "gemini-1.0-pro"
    GEMINI_1_0_PRO_VISION = "gemini-1.0-pro-vision"
    GEMINI_1_5_VISION = "gemini-1.5-vision"
    GEMINI_1_0_PRO_VISION_001 = "gemini-1.0-pro-vision-001"
    GEMINI_1_0_PRO_002 = "gemini-1.0-pro-002"
    GEMINI_1_0_PRO_001 = "gemini-1.0-pro-001"
    CLAUDE_3_HAIKU_20240307 = "claude-3-haiku@20240307"
    CLAUDE_3_SONNET_20240229 = "claude-3-sonnet@20240229"
    CLAUDE_3_OPUS_20240229 = "claude-3-opus@20240229"
    CLAUDE_3_5_SONNET_20240620 = "claude-3-5-sonnet@20240620"
    CLAUDE_3_5_SONNET_V2_20241022 = "claude-3-5-sonnet-v2@20241022"
    CLAUDE_3_5_HAIKU_20241022 = "claude-3-5-haiku@20241022"
    GEMINI_1_5_PRO_001 = "gemini-1.5-pro-001"
    GEMINI_1_5_PRO_PREVIEW_0514 = "gemini-1.5-pro-preview-0514"
    GEMINI_1_5_PRO_PREVIEW_0409 = "gemini-1.5-pro-preview-0409"
    GEMINI_1_5_FLASH_001 = "gemini-1.5-flash-001"
    GEMINI_1_5_FLASH_PREVIEW_0514 = "gemini-1.5-flash-preview-0514"
    TEXTEMBEDDING_GECKO = "textembedding-gecko"
    TEXTEMBEDDING_GECKO_001 = "textembedding-gecko@001"
    TEXTEMBEDDING_GECKO_003 = "textembedding-gecko@003"
    TEXT_EMBEDDING_004 = "text-embedding-004"
    TEXT_EMBEDDING_005 = "text-embedding-005"
    TEXT_EMBEDDING = "text-embedding"
    TEXT_EMBEDDING_PREVIEW_0815 = "text-embedding-preview-0815"
    TEXTEMBEDDING_GECKO_MULTILINGUAL_001 = "textembedding-gecko-multilingual@001"
    TEXT_MULTILINGUAL_EMBEDDING_002 = "text-multilingual-embedding-002"
    IMAGEN_3_0_GENERATE_001 = "imagen-3.0-generate-001"
    IMAGEN_3_0_FAST_GENERATE_001 = "imagen-3.0-fast-generate-001"
    IMAGEGENERATION_006 = "imagegeneration@006"
    IMAGEGENERATION_005 = "imagegeneration@005"
    IMAGEGENERATION_002 = "imagegeneration@002"
    GEMINI_1_5_PRO_002 = "gemini-1.5-pro-002"
    GEMINI_1_5_PRO_002_BATCHX = "gemini-1.5-pro-002-batchx"
    GEMINI_1_5_FLASH_002 = "gemini-1.5-flash-002"
    GEMINI_2_0_FLASH_LITE_PREVIEW_02_05 = "gemini-2.0-flash-lite-preview-02-05"
    GEMINI_2_0_FLASH_001 = "gemini-2.0-flash-001"
    GEMINI_2_0_FLASH = "gemini-2.0-flash"
    CLAUDE_3_7_SONNET_V2_20250219 = "claude-3-7-sonnet-v2@20250219"
    CLAUDE_3_7_SONNET_20250219 = "claude-3-7-sonnet@20250219"
    GEMINI_2_0_FLASH_LITE = "gemini-2.0-flash-lite"
    GEMINI_2_0_FLASH_LITE_001 = "gemini-2.0-flash-lite-001"
    GEMINI_2_5_PRO_PREVIEW_03_25 = "gemini-2.5-pro-preview-03-25"
    GEMINI_2_5_PRO_PREVIEW_05_06 = "gemini-2.5-pro-preview-05-06"
    GEMINI_3_PRO_PREVIEW = "gemini-3-pro-preview"
    GEMINI_3_PRO_PREVIEW_02_05 = "gemini-3-pro-preview-02-05"
    GEMINI_2_5_FLASH_PREVIEW_04_17 = "gemini-2.5-flash-preview-04-17"
    GEMINI_2_5_FLASH_PREVIEW_05_20 = "gemini-2.5-flash-preview-05-20"
    MULTIMODALEMBEDDING_001 = "multimodalembedding@001"
    CLAUDE_SONNET_4_20250514 = "claude-sonnet-4@20250514"
    CLAUDE_SONNET_4 = "claude-sonnet-4"
    CLAUDE_OPUS_4_20250514 = "claude-opus-4@20250514"
    GEMINI_2_5_FLASH_LITE_PREVIEW_06_17 = "gemini-2.5-flash-lite-preview-06-17"
    GEMINI_2_5_FLASH = "gemini-2.5-flash"
    GEMINI_2_5_FLASH_IMAGE = "gemini-2.5-flash-image"
    GEMINI_3_PRO_IMAGE_PREVIEW = "gemini-3-pro-image-preview"
    GEMINI_2_5_PRO = "gemini-2.5-pro"
    GEMINI_2_5_FLASH_LITE = "gemini-2.5-flash-lite"
    LLAMA3_3_LLAMA_3_3_70B_INSTRUCT = "llama3-3@llama-3.3-70b-instruct"
    LLAMA4_LLAMA_4_SCOUT_17B_16E_INSTRUCT = "llama4@llama-4-scout-17b-16e-instruct"
    GEMMA_3_27B_IT = "gemma-3-27b-it"
    QWEN3_QWEN3_32B = "qwen3@qwen3-32b"
    LLAMA3_1_LLAMA_3_1_8B_INSTRUCT = "llama3_1@llama-3.1-8b-instruct"
    LLAMA3_2_LLAMA_3_2_1B_INSTRUCT = "llama3-2@llama-3.2-1b-instruct"
    LLAMA3_2_LLAMA_3_2_3B_INSTRUCT = "llama3-2@llama-3.2-3b-instruct"
    CLAUDE_OPUS_4_1_20250805 = "claude-opus-4-1@20250805"
    GEMINI_2_0_FLASH_EXP_001 = "gemini-2.0-flash-exp-001"
    IMAGEN_4_0_GENERATE_001 = "imagen-4.0-generate-001"
    IMAGEN_4_0_ULTRA_GENERATE_001 = "imagen-4.0-ultra-generate-001"
    IMAGEN_4_0_FAST_GENERATE_001 = "imagen-4.0-fast-generate-001"
    IMAGEN_4_0_GENERATE_PREVIEW_06_06 = "imagen-4.0-generate-preview-06-06"
    IMAGEN_4_0_ULTRA_GENERATE_PREVIEW_06_06 = "imagen-4.0-ultra-generate-preview-06-06"
    IMAGEN_4_0_FAST_GENERATE_PREVIEW_06_06 = "imagen-4.0-fast-generate-preview-06-06"
    IMAGEN_4_0_GENERATE_PREVIEW_05_20 = "imagen-4.0-generate-preview-05-20"
    IMAGEN_4_0_ULTRA_GENERATE_PREVIEW_05_20 = "imagen-4.0-ultra-generate-preview-05-20"
    CLAUDE_SONNET_4_5_20250929 = "claude-sonnet-4-5-20250929"
    CLAUDE_SONNET_4_5_20250929_1 = "claude-sonnet-4-5@20250929"
    CLAUDE_HAIKU_4_5_20251001 = "claude-haiku-4-5-20251001"
    CLAUDE_HAIKU_4_5_20251001_1 = "claude-haiku-4-5@20251001"
    LLAMA_3_1_405B_INSTRUCT_MAAS = "llama-3.1-405b-instruct-maas"
    GEMINI_EMBEDDING_001 = "gemini-embedding-001"
    VEO_3_1_GENERATE_PREVIEW = "veo-3.1-generate-preview"
    VEO_3_1_FAST_GENERATE_PREVIEW = "veo-3.1-fast-generate-preview"
    VEO_3_0_GENERATE_001 = "veo-3.0-generate-001"
    VEO_3_0_FAST_GENERATE_001 = "veo-3.0-fast-generate-001"
    VEO_3_0_GENERATE_PREVIEW = "veo-3.0-generate-preview"
    VEO_3_0_FAST_GENERATE_PREVIEW = "veo-3.0-fast-generate-preview"
    VEO_2_0_GENERATE_001 = "veo-2.0-generate-001"
    VEO_2_0_GENERATE_EXP = "veo-2.0-generate-exp"
    VEO_2_0_GENERATE_PREVIEW = "veo-2.0-generate-preview"
    CLAUDE_OPUS_4_5_20251101 = "claude-opus-4-5-20251101"
    CLAUDE_OPUS_4_5_20251101_1 = "claude-opus-4-5@20251101"
    GEMINI_2_5_FLASH_IMAGE_PREVIEW = "gemini-2.5-flash-image-preview"
    VEO_3_1_FAST_GENERATE_001 = "veo-3.1-fast-generate-001"
    VEO_3_1_GENERATE_001 = "veo-3.1-generate-001"
    GEMINI_3_FLASH_PREVIEW = "gemini-3-flash-preview"


# XAIModels
class XAIModels:
    """XAIModels constants."""
    GROK_2_VISION_1212 = "grok-2-vision-1212"
    GROK_2_1212 = "grok-2-1212"
    GROK_VISION_BETA = "grok-vision-beta"
    GROK_BETA = "grok-beta"
    GROK_4_0709 = "grok-4-0709"
    GROK_4 = "grok-4"
    GROK_4_LATEST = "grok-4-latest"
    GROK_3 = "grok-3"
    GROK_3_LATEST = "grok-3-latest"
    GROK_3_BETA = "grok-3-beta"
    GROK_3_MINI = "grok-3-mini"
    GROK_3_MINI_LATEST = "grok-3-mini-latest"
    GROK_3_MINI_BETA = "grok-3-mini-beta"
    GROK_3_FAST = "grok-3-fast"
    GROK_3_FAST_LATEST = "grok-3-fast-latest"
    GROK_3_FAST_BETA = "grok-3-fast-beta"
    GROK_3_MINI_FAST = "grok-3-mini-fast"
    GROK_3_MINI_FAST_LATEST = "grok-3-mini-fast-latest"
    GROK_3_MINI_FAST_BETA = "grok-3-mini-fast-beta"
    GROK_CODE_FAST_1 = "grok-code-fast-1"
    GROK_2 = "grok-2"
    GROK_2_LATEST = "grok-2-latest"
    GROK_2_VISION = "grok-2-vision"
    GROK_2_VISION_LATEST = "grok-2-vision-latest"
    GROK_4_1_FAST_NON_REASONING = "grok-4-1-fast-non-reasoning"
    GROK_4_1_FAST_NON_REASONING_LATEST = "grok-4-1-fast-non-reasoning-latest"
    GROK_4_1_FAST_REASONING = "grok-4-1-fast-reasoning"
    GROK_4_1_FAST = "grok-4-1-fast"
    GROK_4_1_FAST_REASONING_LATEST = "grok-4-1-fast-reasoning-latest"
    GROK_4_FAST_NON_REASONING = "grok-4-fast-non-reasoning"
    GROK_4_FAST_NON_REASONING_LATEST = "grok-4-fast-non-reasoning-latest"
    GROK_4_FAST_REASONING = "grok-4-fast-reasoning"
    GROK_4_FAST = "grok-4-fast"
    GROK_4_FAST_REASONING_LATEST = "grok-4-fast-reasoning-latest"
    GROK_CODE_FAST = "grok-code-fast"
    GROK_CODE_FAST_1_0825 = "grok-code-fast-1-0825"


# ZhipuModels
class ZhipuModels:
    """ZhipuModels constants."""
    GLM_4_7 = "glm-4.7"
    GLM_4_6 = "glm-4.6"
    GLM_4_5 = "glm-4.5"
    GLM_4_5V = "glm-4.5v"
    GLM_4_5_X = "glm-4.5-x"
    GLM_4_5_AIR = "glm-4.5-air"
    GLM_4_5_AIRX = "glm-4.5-airx"
    GLM_4_32B_0414_128K = "glm-4-32b-0414-128k"
    GLM_4_5_FLASH = "glm-4.5-flash"


# STT Model Aliases
DeepgramSTTModels = DeepgramModels
AzureSpeechSTTModels = AzureSpeechModels
AssemblyAISTTModels = AssemblyAIModels
ElevenLabsSTTModels = ElevenLabsModels
SonioxSTTModels = SonioxModels

# TTS Model Aliases
AmazonPollyTTSModels = AmazonPollyModels
AzureSpeechTTSModels = AzureSpeechModels
DeepgramTTSModels = DeepgramModels
ElevenLabsTTSModels = ElevenLabsModels

# Backward compatibility aliases & Functional exports
def is_model_supported(model: str) -> bool:
    """Check if a model is supported by the SDK."""
    return True

# Model Aliases for backward compatibility and specific use cases
AmazonPollyTTSModels = AmazonPollyModels
AssemblyAISTTModels = AssemblyAIModels
AzureSpeechSTTModels = AzureSpeechModels
AzureSpeechTTSModels = AzureSpeechModels
MicrosoftAzureSpeechModels = AzureSpeechModels
MicrosoftAzureSpeechSTTModels = AzureSpeechModels
MicrosoftAzureSpeechTTSModels = AzureSpeechModels
AWSModels = BedrockModels
DeepgramSTTModels = DeepgramModels
DeepgramTTSModels = DeepgramModels
ElevenLabsSTTModels = ElevenLabsModels
ElevenLabsTTSModels = ElevenLabsModels
GoogleCloudSpeechModels = GoogleCloudSpeechSTTModels
GoogleCloudTTSModels = GoogleCloudTTSTTSModels
GoogleCloudTextToSpeechTTSModels = GoogleCloudTTSTTSModels
GoogleDeepMindModels = GoogleModels
SonioxSTTModels = SonioxModels
MetaModels = TogetherAIModels
MoonshotAIModels = OpenRouterModels # Placeholder for Moonshot models often found in OpenRouter
